#include <unordered_map>
#include <string>

#define __AQ_PNP_PROP(pnp, manu) {pnp, manu}
inline std::unordered_map<std::string, std::string> PNPIDS = {
	__AQ_PNP_PROP("AAA", "Avolites Ltd"),
	__AQ_PNP_PROP("AAE", "Anatek Electronics Inc."),
	__AQ_PNP_PROP("AAM", "Aava Mobile Oy"),
	__AQ_PNP_PROP("AAN", "AAEON Technology Inc."),
	__AQ_PNP_PROP("AAT", "Ann Arbor Technologies"),
	__AQ_PNP_PROP("ABA", "ABBAHOME INC."),
	__AQ_PNP_PROP("ABC", "AboCom System Inc."),
	__AQ_PNP_PROP("ABD", "Allen Bradley Company"),
	__AQ_PNP_PROP("ABE", "Alcatel Bell"),
	__AQ_PNP_PROP("ABO", "D-Link Systems Inc"),
	__AQ_PNP_PROP("ABS", "Abaco Systems, Inc."),
	__AQ_PNP_PROP("ABT", "Anchor Bay Technologies, Inc."),
	__AQ_PNP_PROP("ABV", "Advanced Research Technology"),
	__AQ_PNP_PROP("ACA", "Ariel Corporation"),
	__AQ_PNP_PROP("ACB", "Aculab Ltd"),
	__AQ_PNP_PROP("ACC", "Accton Technology Corporation"),
	__AQ_PNP_PROP("ACD", "AWETA BV"),
	__AQ_PNP_PROP("ACE", "Actek Engineering Pty Ltd"),
	__AQ_PNP_PROP("ACG", "A&R Cambridge Ltd."),
	__AQ_PNP_PROP("ACH", "Archtek Telecom Corporation"),
	__AQ_PNP_PROP("ACI", "Ancor Communications Inc"),
	__AQ_PNP_PROP("ACK", "Acksys"),
	__AQ_PNP_PROP("ACL", "Apricot Computers"),
	__AQ_PNP_PROP("ACM", "Acroloop Motion Control Systems Inc"),
	__AQ_PNP_PROP("ACO", "Allion Computer Inc."),
	__AQ_PNP_PROP("ACP", "Aspen Tech Inc"),
	__AQ_PNP_PROP("ACR", "Acer Technologies"),
	__AQ_PNP_PROP("ACS", "Altos Computer Systems"),
	__AQ_PNP_PROP("ACT", "Applied Creative Technology"),
	__AQ_PNP_PROP("ACU", "Acculogic"),
	__AQ_PNP_PROP("ACV", "ActivCard S.A"),
	__AQ_PNP_PROP("ADA", "Addi-Data GmbH"),
	__AQ_PNP_PROP("ADB", "Aldebbaron"),
	__AQ_PNP_PROP("ADC", "Acnhor Datacomm"),
	__AQ_PNP_PROP("ADD", "Advanced Peripheral Devices Inc"),
	__AQ_PNP_PROP("ADE", "Arithmos, Inc."),
	__AQ_PNP_PROP("ADG", "Airdrop Gaming LLC"),
	__AQ_PNP_PROP("ADH", "Aerodata Holdings Ltd"),
	__AQ_PNP_PROP("ADI", "ADI Systems Inc"),
	__AQ_PNP_PROP("ADK", "Adtek System Science Company Ltd"),
	__AQ_PNP_PROP("ADL", "ASTRA Security Products Ltd"),
	__AQ_PNP_PROP("ADM", "Ad Lib MultiMedia Inc"),
	__AQ_PNP_PROP("ADN", "Analog & Digital Devices Tel. Inc"),
	__AQ_PNP_PROP("ADP", "Adaptec Inc"),
	__AQ_PNP_PROP("ADR", "Nasa Ames Research Center"),
	__AQ_PNP_PROP("ADS", "Analog Devices Inc"),
	__AQ_PNP_PROP("ADT", "Adtek"),
	__AQ_PNP_PROP("ADV", "Advanced Micro Devices Inc"),
	__AQ_PNP_PROP("ADX", "Adax Inc"),
	__AQ_PNP_PROP("ADZ", "ADDER TECHNOLOGY LTD"),
	__AQ_PNP_PROP("AEC", "Antex Electronics Corporation"),
	__AQ_PNP_PROP("AED", "Advanced Electronic Designs, Inc."),
	__AQ_PNP_PROP("AEI", "Actiontec Electric Inc"),
	__AQ_PNP_PROP("AEJ", "Alpha Electronics Company"),
	__AQ_PNP_PROP("AEM", "ASEM S.p.A."),
	__AQ_PNP_PROP("AEN", "Avencall"),
	__AQ_PNP_PROP("AEP", "Aetas Peripheral International"),
	__AQ_PNP_PROP("AET", "Aethra Telecomunicazioni S.r.l."),
	__AQ_PNP_PROP("AFA", "Alfa Inc"),
	__AQ_PNP_PROP("AGC", "Beijing Aerospace Golden Card Electronic Engineering Co.,Ltd."),
	__AQ_PNP_PROP("AGI", "Artish Graphics Inc"),
	__AQ_PNP_PROP("AGL", "Argolis"),
	__AQ_PNP_PROP("AGM", "Advan Int'l Corporation"),
	__AQ_PNP_PROP("AGO", "AlgolTek, Inc."),
	__AQ_PNP_PROP("AGT", "Agilent Technologies"),
	__AQ_PNP_PROP("AHC", "Advantech Co., Ltd."),
	__AQ_PNP_PROP("AHQ", "Astro HQ LLC"),
	__AQ_PNP_PROP("AHS", "Beijing AnHeng SecoTech Information Technology Co., Ltd."),
	__AQ_PNP_PROP("AIC", "Arnos Insturments & Computer Systems"),
	__AQ_PNP_PROP("AIE", "Altmann Industrieelektronik"),
	__AQ_PNP_PROP("AII", "Amptron International Inc."),
	__AQ_PNP_PROP("AIK", "Dongguan Alllike Electronics Co., Ltd."),
	__AQ_PNP_PROP("AIL", "Altos India Ltd"),
	__AQ_PNP_PROP("AIM", "AIMS Lab Inc"),
	__AQ_PNP_PROP("AIR", "Advanced Integ. Research Inc"),
	__AQ_PNP_PROP("AIS", "Alien Internet Services"),
	__AQ_PNP_PROP("AIW", "Aiwa Company Ltd"),
	__AQ_PNP_PROP("AIX", "ALTINEX, INC."),
	__AQ_PNP_PROP("AJA", "AJA Video Systems, Inc."),
	__AQ_PNP_PROP("AKB", "Akebia Ltd"),
	__AQ_PNP_PROP("AKE", "AKAMI Electric Co.,Ltd"),
	__AQ_PNP_PROP("AKI", "AKIA Corporation"),
	__AQ_PNP_PROP("AKL", "AMiT Ltd"),
	__AQ_PNP_PROP("AKM", "Asahi Kasei Microsystems Company Ltd"),
	__AQ_PNP_PROP("AKP", "Atom Komplex Prylad"),
	__AQ_PNP_PROP("AKR", "Anker Innovations Limited"),
	__AQ_PNP_PROP("AKY", "Askey Computer Corporation"),
	__AQ_PNP_PROP("ALA", "Alacron Inc"),
	__AQ_PNP_PROP("ALC", "Altec Corporation"),
	__AQ_PNP_PROP("ALD", "In4S Inc"),
	__AQ_PNP_PROP("ALE", "Alenco BV"),
	__AQ_PNP_PROP("ALG", "Realtek Semiconductor Corp."),
	__AQ_PNP_PROP("ALH", "AL Systems"),
	__AQ_PNP_PROP("ALI", "Acer Labs"),
	__AQ_PNP_PROP("ALJ", "Altec Lansing"),
	__AQ_PNP_PROP("ALK", "Acrolink Inc"),
	__AQ_PNP_PROP("ALL", "Alliance Semiconductor Corporation"),
	__AQ_PNP_PROP("ALM", "Acutec Ltd."),
	__AQ_PNP_PROP("ALN", "Alana Technologies"),
	__AQ_PNP_PROP("ALO", "Algolith Inc."),
	__AQ_PNP_PROP("ALP", "ALPS ALPINE CO., LTD."),
	__AQ_PNP_PROP("ALR", "Advanced Logic"),
	__AQ_PNP_PROP("ALS", "Avance Logic Inc"),
	__AQ_PNP_PROP("ALT", "Altra"),
	__AQ_PNP_PROP("ALV", "AlphaView LCD"),
	__AQ_PNP_PROP("ALX", "ALEXON Co.,Ltd."),
	__AQ_PNP_PROP("AMA", "Asia Microelectronic Development Inc"),
	__AQ_PNP_PROP("AMB", "Ambient Technologies, Inc."),
	__AQ_PNP_PROP("AMC", "Attachmate Corporation"),
	__AQ_PNP_PROP("AMD", "Amdek Corporation"),
	__AQ_PNP_PROP("AMI", "American Megatrends Inc"),
	__AQ_PNP_PROP("AML", "Anderson Multimedia Communications (HK) Limited"),
	__AQ_PNP_PROP("AMN", "Amimon LTD."),
	__AQ_PNP_PROP("AMO", "Amino Technologies PLC and Amino Communications Limited"),
	__AQ_PNP_PROP("AMP", "AMP Inc"),
	__AQ_PNP_PROP("AMR", "AmTRAN Technology Co., Ltd."),
	__AQ_PNP_PROP("AMS", "ARMSTEL, Inc."),
	__AQ_PNP_PROP("AMT", "AMT International Industry"),
	__AQ_PNP_PROP("AMX", "AMX LLC"),
	__AQ_PNP_PROP("ANA", "Anakron"),
	__AQ_PNP_PROP("ANC", "Ancot"),
	__AQ_PNP_PROP("AND", "Adtran Inc"),
	__AQ_PNP_PROP("ANI", "Anigma Inc"),
	__AQ_PNP_PROP("ANK", "Anko Electronic Company Ltd"),
	__AQ_PNP_PROP("ANL", "Analogix Semiconductor, Inc"),
	__AQ_PNP_PROP("ANO", "Anorad Corporation"),
	__AQ_PNP_PROP("ANP", "Andrew Network Production"),
	__AQ_PNP_PROP("ANR", "ANR Ltd"),
	__AQ_PNP_PROP("ANS", "Ansel Communication Company"),
	__AQ_PNP_PROP("ANT", "Ace CAD Enterprise Company Ltd"),
	__AQ_PNP_PROP("ANV", "Beijing ANTVR Technology Co., Ltd."),
	__AQ_PNP_PROP("ANW", "Analog Way SAS"),
	__AQ_PNP_PROP("ANX", "Acer Netxus Inc"),
	__AQ_PNP_PROP("AOA", "AOpen Inc."),
	__AQ_PNP_PROP("AOE", "Advanced Optics Electronics, Inc."),
	__AQ_PNP_PROP("AOL", "America OnLine"),
	__AQ_PNP_PROP("AOT", "Alcatel"),
	__AQ_PNP_PROP("APC", "American Power Conversion"),
	__AQ_PNP_PROP("APD", "AppliAdata"),
	__AQ_PNP_PROP("APE", "ALPS ALPINE CO., LTD."),
	__AQ_PNP_PROP("APG", "Horner Electric Inc"),
	__AQ_PNP_PROP("API", "A Plus Info Corporation"),
	__AQ_PNP_PROP("APL", "Aplicom Oy"),
	__AQ_PNP_PROP("APM", "Applied Memory Tech"),
	__AQ_PNP_PROP("APN", "Appian Tech Inc"),
	__AQ_PNP_PROP("APP", "Apple Computer Inc"),
	__AQ_PNP_PROP("APR", "Aprilia s.p.a."),
	__AQ_PNP_PROP("APS", "Autologic Inc"),
	__AQ_PNP_PROP("APT", "Audio Processing Technology  Ltd"),
	__AQ_PNP_PROP("APV", "A+V Link"),
	__AQ_PNP_PROP("APX", "AP Designs Ltd"),
	__AQ_PNP_PROP("ARC", "Alta Research Corporation"),
	__AQ_PNP_PROP("ARD", "AREC Inc."),
	__AQ_PNP_PROP("ARE", "ICET S.p.A."),
	__AQ_PNP_PROP("ARG", "Argus Electronics Co., LTD"),
	__AQ_PNP_PROP("ARI", "Argosy Research Inc"),
	__AQ_PNP_PROP("ARK", "Ark Logic Inc"),
	__AQ_PNP_PROP("ARL", "Arlotto Comnet Inc"),
	__AQ_PNP_PROP("ARM", "Arima"),
	__AQ_PNP_PROP("ARO", "Poso International B.V."),
	__AQ_PNP_PROP("ARR", "ARRIS Group, Inc."),
	__AQ_PNP_PROP("ARS", "Arescom Inc"),
	__AQ_PNP_PROP("ART", "Corion Industrial Corporation"),
	__AQ_PNP_PROP("ASC", "Ascom Strategic Technology Unit"),
	__AQ_PNP_PROP("ASD", "USC Information Sciences Institute"),
	__AQ_PNP_PROP("ASE", "AseV Display Labs"),
	__AQ_PNP_PROP("ASH", "Ashton Bentley Concepts"),
	__AQ_PNP_PROP("ASI", "Ahead Systems"),
	__AQ_PNP_PROP("ASK", "Ask A/S"),
	__AQ_PNP_PROP("ASL", "AccuScene Corporation Ltd"),
	__AQ_PNP_PROP("ASM", "ASEM S.p.A."),
	__AQ_PNP_PROP("ASN", "Asante Tech Inc"),
	__AQ_PNP_PROP("ASP", "ASP Microelectronics Ltd"),
	__AQ_PNP_PROP("AST", "AST Research Inc"),
	__AQ_PNP_PROP("ASU", "Asuscom Network Inc"),
	__AQ_PNP_PROP("ASX", "AudioScience"),
	__AQ_PNP_PROP("ASY", "Rockwell Collins / Airshow Systems"),
	__AQ_PNP_PROP("ATA", "Allied Telesyn International (Asia) Pte Ltd"),
	__AQ_PNP_PROP("ATC", "Ably-Tech Corporation"),
	__AQ_PNP_PROP("ATD", "Alpha Telecom Inc"),
	__AQ_PNP_PROP("ATE", "Innovate Ltd"),
	__AQ_PNP_PROP("ATH", "Athena Informatica S.R.L."),
	__AQ_PNP_PROP("ATI", "Allied Telesis KK"),
	__AQ_PNP_PROP("ATJ", "ArchiTek Corporation"),
	__AQ_PNP_PROP("ATK", "Allied Telesyn Int'l"),
	__AQ_PNP_PROP("ATL", "Arcus Technology Ltd"),
	__AQ_PNP_PROP("ATM", "ATM Ltd"),
	__AQ_PNP_PROP("ATN", "Athena Smartcard Solutions Ltd."),
	__AQ_PNP_PROP("ATO", "ASTRO DESIGN, INC."),
	__AQ_PNP_PROP("ATP", "Alpha-Top Corporation"),
	__AQ_PNP_PROP("ATT", "AT&T"),
	__AQ_PNP_PROP("ATU", "Avocor Technologies USA, Inc"),
	__AQ_PNP_PROP("ATV", "Office Depot, Inc."),
	__AQ_PNP_PROP("ATX", "Athenix Corporation"),
	__AQ_PNP_PROP("AUD", "AudioControl"),
	__AQ_PNP_PROP("AUG", "August Home, Inc."),
	__AQ_PNP_PROP("AUI", "ALPS ALPINE CO., LTD."),
	__AQ_PNP_PROP("AUO", "AU Optronics"),
	__AQ_PNP_PROP("AUR", "Aureal Semiconductor"),
	__AQ_PNP_PROP("AUS", "ASUSTek COMPUTER INC"),
	__AQ_PNP_PROP("AUT", "Autotime Corporation"),
	__AQ_PNP_PROP("AUV", "Auvidea GmbH"),
	__AQ_PNP_PROP("AVA", "Avaya Communication"),
	__AQ_PNP_PROP("AVC", "Auravision Corporation"),
	__AQ_PNP_PROP("AVD", "Avid Electronics Corporation"),
	__AQ_PNP_PROP("AVE", "Add Value Enterpises (Asia) Pte Ltd"),
	__AQ_PNP_PROP("AVG", "Avegant Corporation"),
	__AQ_PNP_PROP("AVI", "Nippon Avionics Co.,Ltd"),
	__AQ_PNP_PROP("AVJ", "Atelier Vision Corporation"),
	__AQ_PNP_PROP("AVL", "Avalue Technology Inc."),
	__AQ_PNP_PROP("AVM", "AVM GmbH"),
	__AQ_PNP_PROP("AVN", "Advance Computer Corporation"),
	__AQ_PNP_PROP("AVO", "Avocent Corporation"),
	__AQ_PNP_PROP("AVR", "AVer Information Inc."),
	__AQ_PNP_PROP("AVS", "Avatron Software Inc."),
	__AQ_PNP_PROP("AVT", "Avtek (Electronics) Pty Ltd"),
	__AQ_PNP_PROP("AVV", "SBS Technologies (Canada), Inc. (was Avvida Systems, Inc.)"),
	__AQ_PNP_PROP("AVX", "A/Vaux Electronics"),
	__AQ_PNP_PROP("AWC", "Access Works Comm Inc"),
	__AQ_PNP_PROP("AWL", "Aironet Wireless Communications, Inc"),
	__AQ_PNP_PROP("AWS", "Wave Systems"),
	__AQ_PNP_PROP("AXB", "Adrienne Electronics Corporation"),
	__AQ_PNP_PROP("AXC", "AXIOMTEK CO., LTD."),
	__AQ_PNP_PROP("AXE", "Axell Corporation"),
	__AQ_PNP_PROP("AXI", "American Magnetics"),
	__AQ_PNP_PROP("AXL", "Axel"),
	__AQ_PNP_PROP("AXO", "Axonic Labs LLC"),
	__AQ_PNP_PROP("AXP", "American Express"),
	__AQ_PNP_PROP("AXT", "Axtend Technologies Inc"),
	__AQ_PNP_PROP("AXX", "Axxon Computer Corporation"),
	__AQ_PNP_PROP("AXY", "AXYZ Automation Services, Inc"),
	__AQ_PNP_PROP("AYD", "Aydin Displays"),
	__AQ_PNP_PROP("AYR", "Airlib, Inc"),
	__AQ_PNP_PROP("AZH", "Shenzhen three Connaught Information Technology Co., Ltd. (3nod Group)"),
	__AQ_PNP_PROP("AZM", "AZ Middelheim - Radiotherapy"),
	__AQ_PNP_PROP("AZT", "Aztech Systems Ltd"),
	__AQ_PNP_PROP("BAC", "Biometric Access Corporation"),
	__AQ_PNP_PROP("BAN", "Banyan"),
	__AQ_PNP_PROP("BBB", "an-najah university"),
	__AQ_PNP_PROP("BBH", "B&Bh"),
	__AQ_PNP_PROP("BBL", "Brain Boxes Limited"),
	__AQ_PNP_PROP("BBV", "BlueBox Video Limited"),
	__AQ_PNP_PROP("BBX", "Black Box Corporation"),
	__AQ_PNP_PROP("BCC", "Beaver Computer Corporaton"),
	__AQ_PNP_PROP("BCD", "Barco GmbH"),
	__AQ_PNP_PROP("BCI", "Broadata Communications Inc."),
	__AQ_PNP_PROP("BCK", "Beck GmbH & Co. Elektronik Bauelemente KG"),
	__AQ_PNP_PROP("BCM", "Broadcom"),
	__AQ_PNP_PROP("BCQ", "Deutsche Telekom Berkom GmbH"),
	__AQ_PNP_PROP("BCS", "Booria CAD/CAM systems"),
	__AQ_PNP_PROP("BDO", "Brahler ICS"),
	__AQ_PNP_PROP("BDR", "Blonder Tongue Labs, Inc."),
	__AQ_PNP_PROP("BDS", "Barco Display Systems"),
	__AQ_PNP_PROP("BEC", "Beckhoff Automation"),
	__AQ_PNP_PROP("BEI", "Beckworth Enterprises Inc"),
	__AQ_PNP_PROP("BEK", "Beko Elektronik A.S."),
	__AQ_PNP_PROP("BEL", "Beltronic Industrieelektronik GmbH"),
	__AQ_PNP_PROP("BEO", "Baug & Olufsen"),
	__AQ_PNP_PROP("BFE", "B.F. Engineering Corporation"),
	__AQ_PNP_PROP("BFT", "Barnfind Technologies"),
	__AQ_PNP_PROP("BGB", "Barco Graphics N.V"),
	__AQ_PNP_PROP("BGT", "Budzetron Inc"),
	__AQ_PNP_PROP("BHZ", "BitHeadz, Inc."),
	__AQ_PNP_PROP("BIA", "Biamp Systems Corporation"),
	__AQ_PNP_PROP("BIC", "Big Island Communications"),
	__AQ_PNP_PROP("BIG", "Bigscreen, Inc."),
	__AQ_PNP_PROP("BII", "Boeckeler Instruments Inc"),
	__AQ_PNP_PROP("BIL", "Billion Electric Company Ltd"),
	__AQ_PNP_PROP("BIO", "BioLink Technologies International, Inc."),
	__AQ_PNP_PROP("BIT", "Bit 3 Computer"),
	__AQ_PNP_PROP("BLD", "BILD INNOVATIVE TECHNOLOGY LLC"),
	__AQ_PNP_PROP("BLI", "Busicom"),
	__AQ_PNP_PROP("BLN", "BioLink Technologies"),
	__AQ_PNP_PROP("BLP", "Bloomberg L.P."),
	__AQ_PNP_PROP("BMD", "Blackmagic Design"),
	__AQ_PNP_PROP("BMI", "Benson Medical Instruments Company"),
	__AQ_PNP_PROP("BML", "BIOMED Lab"),
	__AQ_PNP_PROP("BMS", "BIOMEDISYS"),
	__AQ_PNP_PROP("BNE", "Bull AB"),
	__AQ_PNP_PROP("BNK", "Banksia Tech Pty Ltd"),
	__AQ_PNP_PROP("BNO", "Bang & Olufsen"),
	__AQ_PNP_PROP("BNS", "Boulder Nonlinear Systems"),
	__AQ_PNP_PROP("BOB", "Rainy Orchard"),
	__AQ_PNP_PROP("BOE", "BOE"),
	__AQ_PNP_PROP("BOI", "NINGBO BOIGLE DIGITAL TECHNOLOGY CO.,LTD"),
	__AQ_PNP_PROP("BOS", "BOS"),
	__AQ_PNP_PROP("BPD", "Micro Solutions, Inc."),
	__AQ_PNP_PROP("BPS", "Barco, N.V."),
	__AQ_PNP_PROP("BPU", "Best Power"),
	__AQ_PNP_PROP("BRA", "Braemac Pty Ltd"),
	__AQ_PNP_PROP("BRC", "BARC"),
	__AQ_PNP_PROP("BRG", "Bridge Information Co., Ltd"),
	__AQ_PNP_PROP("BRI", "Boca Research Inc"),
	__AQ_PNP_PROP("BRL", "Brainlab AG"),
	__AQ_PNP_PROP("BRM", "Braemar Inc"),
	__AQ_PNP_PROP("BRO", "BROTHER INDUSTRIES,LTD."),
	__AQ_PNP_PROP("BSE", "Bose Corporation"),
	__AQ_PNP_PROP("BSG", "Robert Bosch GmbH"),
	__AQ_PNP_PROP("BSL", "Biomedical Systems Laboratory"),
	__AQ_PNP_PROP("BSN", "BRIGHTSIGN, LLC"),
	__AQ_PNP_PROP("BST", "BodySound Technologies, Inc."),
	__AQ_PNP_PROP("BTC", "Bit 3 Computer"),
	__AQ_PNP_PROP("BTE", "Brilliant Technology"),
	__AQ_PNP_PROP("BTF", "Bitfield Oy"),
	__AQ_PNP_PROP("BTI", "BusTech Inc"),
	__AQ_PNP_PROP("BTO", "BioTao Ltd"),
	__AQ_PNP_PROP("BUF", "Yasuhiko Shirai Melco Inc"),
	__AQ_PNP_PROP("BUG", "B.U.G., Inc."),
	__AQ_PNP_PROP("BUJ", "ATI Tech Inc"),
	__AQ_PNP_PROP("BUL", "Bull"),
	__AQ_PNP_PROP("BUR", "B&R Industrial Automation GmbH"),
	__AQ_PNP_PROP("BUS", "BusTek"),
	__AQ_PNP_PROP("BUT", "21ST CENTURY ENTERTAINMENT"),
	__AQ_PNP_PROP("BWK", "Bitworks Inc."),
	__AQ_PNP_PROP("BXE", "Buxco Electronics"),
	__AQ_PNP_PROP("BYD", "byd:sign corporation"),
	__AQ_PNP_PROP("CAA", "Castles Automation Co., Ltd"),
	__AQ_PNP_PROP("CAC", "CA & F Elettronica"),
	__AQ_PNP_PROP("CAG", "CalComp"),
	__AQ_PNP_PROP("CAI", "Canon Inc."),
	__AQ_PNP_PROP("CAL", "Acon"),
	__AQ_PNP_PROP("CAM", "Cambridge Audio"),
	__AQ_PNP_PROP("CAN", "Canopus Company Ltd"),
	__AQ_PNP_PROP("CAR", "Cardinal Company Ltd"),
	__AQ_PNP_PROP("CAS", "CASIO COMPUTER CO.,LTD"),
	__AQ_PNP_PROP("CAT", "Consultancy in Advanced Technology"),
	__AQ_PNP_PROP("CAV", "Cavium Networks, Inc"),
	__AQ_PNP_PROP("CBI", "ComputerBoards Inc"),
	__AQ_PNP_PROP("CBR", "Cebra Tech A/S"),
	__AQ_PNP_PROP("CBT", "Cabletime Ltd"),
	__AQ_PNP_PROP("CBX", "Cybex Computer Products Corporation"),
	__AQ_PNP_PROP("CCC", "C-Cube Microsystems"),
	__AQ_PNP_PROP("CCI", "Cache"),
	__AQ_PNP_PROP("CCJ", "CONTEC CO.,LTD."),
	__AQ_PNP_PROP("CCL", "CCL/ITRI"),
	__AQ_PNP_PROP("CCP", "Capetronic USA Inc"),
	__AQ_PNP_PROP("CDC", "Core Dynamics Corporation"),
	__AQ_PNP_PROP("CDD", "Convergent Data Devices"),
	__AQ_PNP_PROP("CDE", "Colin.de"),
	__AQ_PNP_PROP("CDG", "Christie Digital Systems Inc"),
	__AQ_PNP_PROP("CDI", "Concept Development Inc"),
	__AQ_PNP_PROP("CDK", "Cray Communications"),
	__AQ_PNP_PROP("CDN", "Codenoll Technical Corporation"),
	__AQ_PNP_PROP("CDP", "CalComp"),
	__AQ_PNP_PROP("CDS", "Computer Diagnostic Systems"),
	__AQ_PNP_PROP("CDT", "IBM Corporation"),
	__AQ_PNP_PROP("CDV", "Convergent Design Inc."),
	__AQ_PNP_PROP("CEA", "Consumer Electronics Association"),
	__AQ_PNP_PROP("CEC", "Chicony Electronics Company Ltd"),
	__AQ_PNP_PROP("CED", "Cambridge Electronic Design Ltd"),
	__AQ_PNP_PROP("CEF", "Cefar Digital Vision"),
	__AQ_PNP_PROP("CEI", "Crestron Electronics, Inc."),
	__AQ_PNP_PROP("CEM", "MEC Electronics GmbH"),
	__AQ_PNP_PROP("CEN", "Centurion Technologies P/L"),
	__AQ_PNP_PROP("CEP", "C-DAC"),
	__AQ_PNP_PROP("CER", "Ceronix"),
	__AQ_PNP_PROP("CET", "TEC CORPORATION"),
	__AQ_PNP_PROP("CFG", "Atlantis"),
	__AQ_PNP_PROP("CFR", "Meta View, Inc."),
	__AQ_PNP_PROP("CGA", "Chunghwa Picture Tubes, LTD"),
	__AQ_PNP_PROP("CGS", "Chyron Corp"),
	__AQ_PNP_PROP("CGT", "congatec AG"),
	__AQ_PNP_PROP("CHA", "Chase Research PLC"),
	__AQ_PNP_PROP("CHD", "ChangHong Electric Co.,Ltd"),
	__AQ_PNP_PROP("CHE", "Acer Inc"),
	__AQ_PNP_PROP("CHG", "Sichuan Changhong Electric CO, LTD."),
	__AQ_PNP_PROP("CHI", "Chrontel Inc"),
	__AQ_PNP_PROP("CHL", "Chloride-R&D"),
	__AQ_PNP_PROP("CHM", "CHIC TECHNOLOGY CORP."),
	__AQ_PNP_PROP("CHO", "Sichuang Changhong Corporation"),
	__AQ_PNP_PROP("CHP", "CH Products"),
	__AQ_PNP_PROP("CHR", "christmann informationstechnik + medien GmbH & Co. KG"),
	__AQ_PNP_PROP("CHS", "Agentur Chairos"),
	__AQ_PNP_PROP("CHT", "Chunghwa Picture Tubes,LTD."),
	__AQ_PNP_PROP("CHY", "Cherry GmbH"),
	__AQ_PNP_PROP("CIC", "Comm. Intelligence Corporation"),
	__AQ_PNP_PROP("CID", "Indicates an identity defined by CTS/DID Standards other than EDID"),
	__AQ_PNP_PROP("CIE", "Convergent Engineering, Inc."),
	__AQ_PNP_PROP("CII", "Cromack Industries Inc"),
	__AQ_PNP_PROP("CIL", "Citicom Infotech Private Limited"),
	__AQ_PNP_PROP("CIN", "Citron GmbH"),
	__AQ_PNP_PROP("CIP", "Ciprico Inc"),
	__AQ_PNP_PROP("CIR", "Cirrus Logic Inc"),
	__AQ_PNP_PROP("CIS", "Cisco Systems Inc"),
	__AQ_PNP_PROP("CIT", "Citifax Limited"),
	__AQ_PNP_PROP("CKC", "The Concept Keyboard Company Ltd"),
	__AQ_PNP_PROP("CKJ", "Carina System Co., Ltd."),
	__AQ_PNP_PROP("CLA", "Clarion Company Ltd"),
	__AQ_PNP_PROP("CLD", "COMMAT L.t.d."),
	__AQ_PNP_PROP("CLE", "Classe Audio"),
	__AQ_PNP_PROP("CLG", "CoreLogic"),
	__AQ_PNP_PROP("CLI", "Cirrus Logic Inc"),
	__AQ_PNP_PROP("CLM", "CrystaLake Multimedia"),
	__AQ_PNP_PROP("CLO", "Clone Computers"),
	__AQ_PNP_PROP("CLR", "Clover Electronics"),
	__AQ_PNP_PROP("CLT", "automated computer control systems"),
	__AQ_PNP_PROP("CLV", "Clevo Company"),
	__AQ_PNP_PROP("CLX", "CardLogix"),
	__AQ_PNP_PROP("CMC", "CMC Ltd"),
	__AQ_PNP_PROP("CMD", "Colorado MicroDisplay, Inc."),
	__AQ_PNP_PROP("CMG", "Chenming Mold Ind. Corp."),
	__AQ_PNP_PROP("CMI", "C-Media Electronics"),
	__AQ_PNP_PROP("CMK", "Comark LLC"),
	__AQ_PNP_PROP("CMM", "Comtime GmbH"),
	__AQ_PNP_PROP("CMN", "Chimei Innolux Corporation"),
	__AQ_PNP_PROP("CMO", "Chi Mei Optoelectronics corp."),
	__AQ_PNP_PROP("CMR", "Cambridge Research Systems Ltd"),
	__AQ_PNP_PROP("CMS", "CompuMaster Srl"),
	__AQ_PNP_PROP("CMX", "Comex Electronics AB"),
	__AQ_PNP_PROP("CNB", "American Power Conversion"),
	__AQ_PNP_PROP("CNC", "Alvedon Computers Ltd"),
	__AQ_PNP_PROP("CND", "Micro-Star Int'l Co., Ltd."),
	__AQ_PNP_PROP("CNE", "Cine-tal"),
	__AQ_PNP_PROP("CNI", "Connect Int'l A/S"),
	__AQ_PNP_PROP("CNN", "Canon Inc"),
	__AQ_PNP_PROP("CNT", "COINT Multimedia Systems"),
	__AQ_PNP_PROP("COB", "COBY Electronics Co., Ltd"),
	__AQ_PNP_PROP("COD", "CODAN Pty. Ltd."),
	__AQ_PNP_PROP("COI", "Codec Inc."),
	__AQ_PNP_PROP("COL", "Rockwell Collins, Inc."),
	__AQ_PNP_PROP("COM", "Comtrol Corporation"),
	__AQ_PNP_PROP("CON", "Contec Company Ltd"),
	__AQ_PNP_PROP("COO", "coolux GmbH"),
	__AQ_PNP_PROP("COR", "Corollary Inc"),
	__AQ_PNP_PROP("COS", "CoStar Corporation"),
	__AQ_PNP_PROP("COT", "Core Technology Inc"),
	__AQ_PNP_PROP("COW", "Polycow Productions"),
	__AQ_PNP_PROP("COX", "Comrex"),
	__AQ_PNP_PROP("CPC", "Ciprico Inc"),
	__AQ_PNP_PROP("CPD", "CompuAdd"),
	__AQ_PNP_PROP("CPI", "Computer Peripherals Inc"),
	__AQ_PNP_PROP("CPL", "Compal Electronics Inc"),
	__AQ_PNP_PROP("CPM", "Capella Microsystems Inc."),
	__AQ_PNP_PROP("CPP", "Compound Photonics"),
	__AQ_PNP_PROP("CPQ", "Compaq Computer Company"),
	__AQ_PNP_PROP("CPT", "cPATH"),
	__AQ_PNP_PROP("CPX", "Powermatic Data Systems"),
	__AQ_PNP_PROP("CRA", "CRALTECH ELECTRONICA, S.L."),
	__AQ_PNP_PROP("CRC", "CONRAC GmbH"),
	__AQ_PNP_PROP("CRD", "Cardinal Technical Inc"),
	__AQ_PNP_PROP("CRE", "Creative Labs Inc"),
	__AQ_PNP_PROP("CRH", "Contemporary Research Corp."),
	__AQ_PNP_PROP("CRI", "Crio Inc."),
	__AQ_PNP_PROP("CRL", "Creative Logic"),
	__AQ_PNP_PROP("CRM", "CORSAIR MEMORY Inc."),
	__AQ_PNP_PROP("CRN", "Cornerstone Imaging"),
	__AQ_PNP_PROP("CRO", "Extraordinary Technologies PTY Limited"),
	__AQ_PNP_PROP("CRQ", "Cirque Corporation"),
	__AQ_PNP_PROP("CRS", "Crescendo Communication Inc"),
	__AQ_PNP_PROP("CRV", "Cerevo Inc."),
	__AQ_PNP_PROP("CRW", "Cammegh Limited"),
	__AQ_PNP_PROP("CRX", "Cyrix Corporation"),
	__AQ_PNP_PROP("CSB", "Transtex SA"),
	__AQ_PNP_PROP("CSC", "Crystal Semiconductor"),
	__AQ_PNP_PROP("CSD", "Cresta Systems Inc"),
	__AQ_PNP_PROP("CSE", "Concept Solutions & Engineering"),
	__AQ_PNP_PROP("CSI", "Cabletron System Inc"),
	__AQ_PNP_PROP("CSL", "Cloudium Systems Ltd."),
	__AQ_PNP_PROP("CSM", "Cosmic Engineering Inc."),
	__AQ_PNP_PROP("CSO", "California Institute of Technology"),
	__AQ_PNP_PROP("CSS", "CSS Laboratories"),
	__AQ_PNP_PROP("CST", "CSTI Inc"),
	__AQ_PNP_PROP("CSW", "China Star Optoelectronics Technology Co., Ltd"),
	__AQ_PNP_PROP("CTA", "CoSystems Inc"),
	__AQ_PNP_PROP("CTC", "CTC Communication Development Company Ltd"),
	__AQ_PNP_PROP("CTE", "Chunghwa Telecom Co., Ltd."),
	__AQ_PNP_PROP("CTL", "Creative Technology Ltd"),
	__AQ_PNP_PROP("CTM", "Computerm Corporation"),
	__AQ_PNP_PROP("CTN", "Computone Products"),
	__AQ_PNP_PROP("CTP", "Computer Technology Corporation"),
	__AQ_PNP_PROP("CTR", "Control4 Corporation"),
	__AQ_PNP_PROP("CTS", "Comtec Systems Co., Ltd."),
	__AQ_PNP_PROP("CTX", "Creatix Polymedia GmbH"),
	__AQ_PNP_PROP("CUB", "Cubix Corporation"),
	__AQ_PNP_PROP("CUK", "Calibre UK Ltd"),
	__AQ_PNP_PROP("CVA", "Covia Inc."),
	__AQ_PNP_PROP("CVI", "Colorado Video, Inc."),
	__AQ_PNP_PROP("CVP", "Chromatec Video Products Ltd"),
	__AQ_PNP_PROP("CVS", "Clarity Visual Systems"),
	__AQ_PNP_PROP("CWC", "Curtiss-Wright Controls, Inc."),
	__AQ_PNP_PROP("CWR", "Connectware Inc"),
	__AQ_PNP_PROP("CXT", "Conexant Systems"),
	__AQ_PNP_PROP("CYB", "CyberVision"),
	__AQ_PNP_PROP("CYC", "Cylink Corporation"),
	__AQ_PNP_PROP("CYD", "Cyclades Corporation"),
	__AQ_PNP_PROP("CYL", "Cyberlabs"),
	__AQ_PNP_PROP("CYP", "CYPRESS SEMICONDUCTOR CORPORATION"),
	__AQ_PNP_PROP("CYT", "Cytechinfo Inc"),
	__AQ_PNP_PROP("CYV", "Cyviz AS"),
	__AQ_PNP_PROP("CYW", "Cyberware"),
	__AQ_PNP_PROP("CYX", "Cyrix Corporation"),
	__AQ_PNP_PROP("CZC", "Shenzhen ChuangZhiCheng Technology Co., Ltd."),
	__AQ_PNP_PROP("CZE", "Carl Zeiss AG"),
	__AQ_PNP_PROP("DAC", "Digital Acoustics Corporation"),
	__AQ_PNP_PROP("DAE", "Digatron Industrie Elektronik GmbH"),
	__AQ_PNP_PROP("DAI", "DAIS SET Ltd."),
	__AQ_PNP_PROP("DAK", "Daktronics"),
	__AQ_PNP_PROP("DAL", "Digital Audio Labs Inc"),
	__AQ_PNP_PROP("DAN", "Danelec Marine A/S"),
	__AQ_PNP_PROP("DAS", "DAVIS AS"),
	__AQ_PNP_PROP("DAT", "Datel Inc"),
	__AQ_PNP_PROP("DAU", "Daou Tech Inc"),
	__AQ_PNP_PROP("DAV", "Davicom Semiconductor Inc"),
	__AQ_PNP_PROP("DAW", "DA2 Technologies Inc"),
	__AQ_PNP_PROP("DAX", "Data Apex Ltd"),
	__AQ_PNP_PROP("DBD", "Diebold Inc."),
	__AQ_PNP_PROP("DBI", "DigiBoard Inc"),
	__AQ_PNP_PROP("DBK", "Databook Inc"),
	__AQ_PNP_PROP("DBL", "Doble Engineering Company"),
	__AQ_PNP_PROP("DBN", "DB Networks Inc"),
	__AQ_PNP_PROP("DCA", "Digital Communications Association"),
	__AQ_PNP_PROP("DCC", "Dale Computer Corporation"),
	__AQ_PNP_PROP("DCD", "Datacast LLC"),
	__AQ_PNP_PROP("DCE", "dSPACE GmbH"),
	__AQ_PNP_PROP("DCI", "Concepts Inc"),
	__AQ_PNP_PROP("DCL", "Dynamic Controls Ltd"),
	__AQ_PNP_PROP("DCM", "DCM Data Products"),
	__AQ_PNP_PROP("DCO", "Dialogue Technology Corporation"),
	__AQ_PNP_PROP("DCR", "Decros Ltd"),
	__AQ_PNP_PROP("DCS", "Diamond Computer Systems Inc"),
	__AQ_PNP_PROP("DCT", "Dancall Telecom A/S"),
	__AQ_PNP_PROP("DCV", "Datatronics Technology Inc"),
	__AQ_PNP_PROP("DDA", "DA2 Technologies Corporation"),
	__AQ_PNP_PROP("DDD", "Danka Data Devices"),
	__AQ_PNP_PROP("DDE", "Datasat Digital Entertainment"),
	__AQ_PNP_PROP("DDI", "Data Display AG"),
	__AQ_PNP_PROP("DDS", "Barco, N.V."),
	__AQ_PNP_PROP("DDT", "Datadesk Technologies Inc"),
	__AQ_PNP_PROP("DDV", "Delta Information Systems, Inc"),
	__AQ_PNP_PROP("DEC", "Digital Equipment Corporation"),
	__AQ_PNP_PROP("DEF", "DEIF A/S"),
	__AQ_PNP_PROP("DEI", "Deico Electronics"),
	__AQ_PNP_PROP("DEL", "Dell Inc."),
	__AQ_PNP_PROP("DEM", "DemoPad Software Ltd"),
	__AQ_PNP_PROP("DEN", "Densitron Computers Ltd"),
	__AQ_PNP_PROP("DEX", "idex displays"),
	__AQ_PNP_PROP("DFI", "DFI"),
	__AQ_PNP_PROP("DFK", "SharkTec A/S"),
	__AQ_PNP_PROP("DFT", "DEI Holdings dba Definitive Technology"),
	__AQ_PNP_PROP("DGA", "Digiital Arts Inc"),
	__AQ_PNP_PROP("DGC", "Data General Corporation"),
	__AQ_PNP_PROP("DGI", "DIGI International"),
	__AQ_PNP_PROP("DGK", "DugoTech Co., LTD"),
	__AQ_PNP_PROP("DGP", "Digicorp European sales S.A."),
	__AQ_PNP_PROP("DGS", "Diagsoft Inc"),
	__AQ_PNP_PROP("DGT", "Dearborn Group Technology"),
	__AQ_PNP_PROP("DHD", "Dension Audio Systems"),
	__AQ_PNP_PROP("DHP", "DH Print"),
	__AQ_PNP_PROP("DHQ", "Quadram"),
	__AQ_PNP_PROP("DHT", "Projectavision Inc"),
	__AQ_PNP_PROP("DIA", "Diadem"),
	__AQ_PNP_PROP("DIG", "Digicom S.p.A."),
	__AQ_PNP_PROP("DII", "Dataq Instruments Inc"),
	__AQ_PNP_PROP("DIM", "dPict Imaging, Inc."),
	__AQ_PNP_PROP("DIN", "Daintelecom Co., Ltd"),
	__AQ_PNP_PROP("DIS", "Diseda S.A."),
	__AQ_PNP_PROP("DIT", "Dragon Information Technology"),
	__AQ_PNP_PROP("DJE", "Capstone Visual Product Development"),
	__AQ_PNP_PROP("DJP", "Maygay Machines, Ltd"),
	__AQ_PNP_PROP("DKY", "Datakey Inc"),
	__AQ_PNP_PROP("DLB", "Dolby Laboratories Inc."),
	__AQ_PNP_PROP("DLC", "Diamond Lane Comm. Corporation"),
	__AQ_PNP_PROP("DLD", "Delem"),
	__AQ_PNP_PROP("DLG", "Digital-Logic GmbH"),
	__AQ_PNP_PROP("DLK", "D-Link Systems Inc"),
	__AQ_PNP_PROP("DLL", "Dell Inc"),
	__AQ_PNP_PROP("DLM", "DLOGIC Ltd."),
	__AQ_PNP_PROP("DLO", "Shenzhen Dlodlo Technologies Co., Ltd."),
	__AQ_PNP_PROP("DLT", "Digitelec Informatique Park Cadera"),
	__AQ_PNP_PROP("DMB", "Digicom Systems Inc"),
	__AQ_PNP_PROP("DMC", "Dune Microsystems Corporation"),
	__AQ_PNP_PROP("DMG", "Monoprice.Inc"),
	__AQ_PNP_PROP("DMM", "Dimond Multimedia Systems Inc"),
	__AQ_PNP_PROP("DMN", "Dimension Engineering LLC"),
	__AQ_PNP_PROP("DMO", "Data Modul AG"),
	__AQ_PNP_PROP("DMP", "D&M Holdings Inc, Professional Business Company"),
	__AQ_PNP_PROP("DMS", "DOME imaging systems"),
	__AQ_PNP_PROP("DMT", "Distributed Management Task Force, Inc. (DMTF)"),
	__AQ_PNP_PROP("DMV", "NDS Ltd"),
	__AQ_PNP_PROP("DNA", "DNA Enterprises, Inc."),
	__AQ_PNP_PROP("DNG", "Apache Micro Peripherals Inc"),
	__AQ_PNP_PROP("DNI", "Deterministic Networks Inc."),
	__AQ_PNP_PROP("DNT", "Dr. Neuhous Telekommunikation GmbH"),
	__AQ_PNP_PROP("DNV", "DiCon"),
	__AQ_PNP_PROP("DOL", "Dolman Technologies Group Inc"),
	__AQ_PNP_PROP("DOM", "Dome Imaging Systems"),
	__AQ_PNP_PROP("DON", "DENON, Ltd."),
	__AQ_PNP_PROP("DOT", "Dotronic Mikroelektronik GmbH"),
	__AQ_PNP_PROP("DPA", "DigiTalk Pro AV"),
	__AQ_PNP_PROP("DPC", "Delta Electronics Inc"),
	__AQ_PNP_PROP("DPH", "Delphi Automotive LLP"),
	__AQ_PNP_PROP("DPI", "DocuPoint"),
	__AQ_PNP_PROP("DPL", "Digital Projection Limited"),
	__AQ_PNP_PROP("DPM", "ADPM Synthesis sas"),
	__AQ_PNP_PROP("DPN", "Shanghai Lexiang Technology Limited"),
	__AQ_PNP_PROP("DPS", "Digital Processing Systems"),
	__AQ_PNP_PROP("DPT", "DPT"),
	__AQ_PNP_PROP("DPX", "DpiX, Inc."),
	__AQ_PNP_PROP("DQB", "Datacube Inc"),
	__AQ_PNP_PROP("DRB", "Dr. Bott KG"),
	__AQ_PNP_PROP("DRC", "Data Ray Corp."),
	__AQ_PNP_PROP("DRD", "DIGITAL REFLECTION INC."),
	__AQ_PNP_PROP("DRI", "Data Race Inc"),
	__AQ_PNP_PROP("DRS", "DRS Defense Solutions, LLC"),
	__AQ_PNP_PROP("DSA", "Display Solution AG"),
	__AQ_PNP_PROP("DSD", "DS Multimedia Pte Ltd"),
	__AQ_PNP_PROP("DSG", "Disguise Technologies"),
	__AQ_PNP_PROP("DSI", "Digitan Systems Inc"),
	__AQ_PNP_PROP("DSJ", "VR Technology Holdings Limited"),
	__AQ_PNP_PROP("DSM", "DSM Digital Services GmbH"),
	__AQ_PNP_PROP("DSP", "Domain Technology Inc"),
	__AQ_PNP_PROP("DTA", "DELTATEC"),
	__AQ_PNP_PROP("DTC", "DTC Tech Corporation"),
	__AQ_PNP_PROP("DTE", "Dimension Technologies, Inc."),
	__AQ_PNP_PROP("DTI", "Diversified Technology, Inc."),
	__AQ_PNP_PROP("DTK", "Dynax Electronics (HK) Ltd"),
	__AQ_PNP_PROP("DTL", "e-Net Inc"),
	__AQ_PNP_PROP("DTM", "Daten Tecnologia"),
	__AQ_PNP_PROP("DTN", "Datang  Telephone Co"),
	__AQ_PNP_PROP("DTO", "Deutsche Thomson OHG"),
	__AQ_PNP_PROP("DTT", "Design & Test Technology, Inc."),
	__AQ_PNP_PROP("DTX", "Data Translation"),
	__AQ_PNP_PROP("DUA", "Dosch & Amand GmbH & Company KG"),
	__AQ_PNP_PROP("DUN", "NCR Corporation"),
	__AQ_PNP_PROP("DVD", "Dictaphone Corporation"),
	__AQ_PNP_PROP("DVL", "Devolo AG"),
	__AQ_PNP_PROP("DVS", "Digital Video System"),
	__AQ_PNP_PROP("DVT", "Data Video"),
	__AQ_PNP_PROP("DWE", "Daewoo Electronics Company Ltd"),
	__AQ_PNP_PROP("DXC", "Digipronix Control Systems"),
	__AQ_PNP_PROP("DXD", "DECIMATOR DESIGN PTY LTD"),
	__AQ_PNP_PROP("DXL", "Dextera Labs Inc"),
	__AQ_PNP_PROP("DXN", "Dixon Technologies (India) Limited"),
	__AQ_PNP_PROP("DXP", "Data Expert Corporation"),
	__AQ_PNP_PROP("DXS", "Signet"),
	__AQ_PNP_PROP("DYC", "Dycam Inc"),
	__AQ_PNP_PROP("DYM", "Dymo-CoStar Corporation"),
	__AQ_PNP_PROP("DYN", "Askey Computer Corporation"),
	__AQ_PNP_PROP("DYX", "Dynax Electronics (HK) Ltd"),
	__AQ_PNP_PROP("EAC", "Emotiva Audio Corp."),
	__AQ_PNP_PROP("EAG", "ELTEC Elektronik AG"),
	__AQ_PNP_PROP("EAS", "Evans and Sutherland Computer"),
	__AQ_PNP_PROP("EBH", "Data Price Informatica"),
	__AQ_PNP_PROP("EBS", "EBS Euchner Büro- und Schulsysteme GmbH"),
	__AQ_PNP_PROP("EBT", "HUALONG TECHNOLOGY CO., LTD"),
	__AQ_PNP_PROP("ECA", "Electro Cam Corp."),
	__AQ_PNP_PROP("ECC", "ESSential Comm. Corporation"),
	__AQ_PNP_PROP("ECH", "EchoStar Corporation"),
	__AQ_PNP_PROP("ECI", "Enciris Technologies"),
	__AQ_PNP_PROP("ECK", "Eugene Chukhlomin Sole Proprietorship, d.b.a."),
	__AQ_PNP_PROP("ECL", "Excel Company Ltd"),
	__AQ_PNP_PROP("ECM", "E-Cmos Tech Corporation"),
	__AQ_PNP_PROP("ECO", "Echo Speech Corporation"),
	__AQ_PNP_PROP("ECP", "Elecom Company Ltd"),
	__AQ_PNP_PROP("ECS", "Elitegroup Computer Systems Company Ltd"),
	__AQ_PNP_PROP("ECT", "Enciris Technologies"),
	__AQ_PNP_PROP("EDC", "e.Digital Corporation"),
	__AQ_PNP_PROP("EDG", "Electronic-Design GmbH"),
	__AQ_PNP_PROP("EDI", "Edimax Tech. Company Ltd"),
	__AQ_PNP_PROP("EDM", "EDMI"),
	__AQ_PNP_PROP("EDT", "Emerging Display Technologies Corp"),
	__AQ_PNP_PROP("EEE", "ET&T Technology Company Ltd"),
	__AQ_PNP_PROP("EEH", "EEH Datalink GmbH"),
	__AQ_PNP_PROP("EEI", "ELARABY COMPANY FOR ENGINEERING INDUSTRIES"),
	__AQ_PNP_PROP("EEP", "E.E.P.D. GmbH"),
	__AQ_PNP_PROP("EES", "EE Solutions, Inc."),
	__AQ_PNP_PROP("EGA", "Elgato Systems LLC"),
	__AQ_PNP_PROP("EGD", "EIZO GmbH Display Technologies"),
	__AQ_PNP_PROP("EGL", "Eagle Technology"),
	__AQ_PNP_PROP("EGN", "Egenera, Inc."),
	__AQ_PNP_PROP("EGO", "Ergo Electronics"),
	__AQ_PNP_PROP("EHJ", "Epson Research"),
	__AQ_PNP_PROP("EHN", "Enhansoft"),
	__AQ_PNP_PROP("EIC", "Eicon Technology Corporation"),
	__AQ_PNP_PROP("EIN", "Elegant Invention"),
	__AQ_PNP_PROP("EKA", "MagTek Inc."),
	__AQ_PNP_PROP("EKC", "Eastman Kodak Company"),
	__AQ_PNP_PROP("EKS", "EKSEN YAZILIM"),
	__AQ_PNP_PROP("ELA", "ELAD srl"),
	__AQ_PNP_PROP("ELC", "Electro Scientific Ind"),
	__AQ_PNP_PROP("ELD", "Express Luck, Inc."),
	__AQ_PNP_PROP("ELE", "Elecom Company Ltd"),
	__AQ_PNP_PROP("ELG", "Elmeg GmbH Kommunikationstechnik"),
	__AQ_PNP_PROP("ELI", "Edsun Laboratories"),
	__AQ_PNP_PROP("ELL", "Electrosonic Ltd"),
	__AQ_PNP_PROP("ELM", "Elmic Systems Inc"),
	__AQ_PNP_PROP("ELO", "Elo TouchSystems Inc"),
	__AQ_PNP_PROP("ELS", "ELSA GmbH"),
	__AQ_PNP_PROP("ELT", "Element Labs, Inc."),
	__AQ_PNP_PROP("ELU", "Express Industrial, Ltd."),
	__AQ_PNP_PROP("ELX", "Elonex PLC"),
	__AQ_PNP_PROP("EMB", "Embedded computing inc ltd"),
	__AQ_PNP_PROP("EMC", "eMicro Corporation"),
	__AQ_PNP_PROP("EMD", "Embrionix Design Inc."),
	__AQ_PNP_PROP("EME", "EMiNE TECHNOLOGY COMPANY, LTD."),
	__AQ_PNP_PROP("EMG", "EMG Consultants Inc"),
	__AQ_PNP_PROP("EMI", "Ex Machina Inc"),
	__AQ_PNP_PROP("EMK", "Emcore Corporation"),
	__AQ_PNP_PROP("EMO", "ELMO COMPANY, LIMITED"),
	__AQ_PNP_PROP("EMR", "ICC Intelligent Platforms GmbH"),
	__AQ_PNP_PROP("EMU", "Emulex Corporation"),
	__AQ_PNP_PROP("ENC", "Eizo Nanao Corporation"),
	__AQ_PNP_PROP("END", "ENIDAN Technologies Ltd"),
	__AQ_PNP_PROP("ENE", "ENE Technology Inc."),
	__AQ_PNP_PROP("ENI", "Efficient Networks"),
	__AQ_PNP_PROP("ENS", "Ensoniq Corporation"),
	__AQ_PNP_PROP("ENT", "Enterprise Comm. & Computing Inc"),
	__AQ_PNP_PROP("EON", "Eon Instrumentation, Inc."),
	__AQ_PNP_PROP("EPC", "Empac"),
	__AQ_PNP_PROP("EPH", "Epiphan Systems Inc."),
	__AQ_PNP_PROP("EPI", "Envision Peripherals, Inc"),
	__AQ_PNP_PROP("EPN", "EPiCON Inc."),
	__AQ_PNP_PROP("EPS", "KEPS"),
	__AQ_PNP_PROP("EQP", "Equipe Electronics Ltd."),
	__AQ_PNP_PROP("EQX", "Equinox Systems Inc"),
	__AQ_PNP_PROP("ERG", "Ergo System"),
	__AQ_PNP_PROP("ERI", "Ericsson Mobile Communications AB"),
	__AQ_PNP_PROP("ERN", "Ericsson, Inc."),
	__AQ_PNP_PROP("ERP", "Euraplan GmbH"),
	__AQ_PNP_PROP("ERS", "Eizo Rugged Solutions"),
	__AQ_PNP_PROP("ERT", "Escort Insturments Corporation"),
	__AQ_PNP_PROP("ESA", "Elbit Systems of America"),
	__AQ_PNP_PROP("ESB", "ScioTeq"),
	__AQ_PNP_PROP("ESC", "Eden Sistemas de Computacao S/A"),
	__AQ_PNP_PROP("ESD", "Ensemble Designs, Inc"),
	__AQ_PNP_PROP("ESG", "ELCON Systemtechnik GmbH"),
	__AQ_PNP_PROP("ESI", "Extended Systems, Inc."),
	__AQ_PNP_PROP("ESK", "ES&S"),
	__AQ_PNP_PROP("ESL", "Esterline Technologies"),
	__AQ_PNP_PROP("ESN", "eSATURNUS"),
	__AQ_PNP_PROP("ESS", "ESS Technology Inc"),
	__AQ_PNP_PROP("EST", "Embedded Solution Technology"),
	__AQ_PNP_PROP("ESY", "E-Systems Inc"),
	__AQ_PNP_PROP("ETC", "Everton Technology Company Ltd"),
	__AQ_PNP_PROP("ETD", "ELAN MICROELECTRONICS CORPORATION"),
	__AQ_PNP_PROP("ETG", "Eizo Technologies GmbH"),
	__AQ_PNP_PROP("ETH", "Etherboot Project"),
	__AQ_PNP_PROP("ETI", "Eclipse Tech Inc"),
	__AQ_PNP_PROP("ETK", "eTEK Labs Inc."),
	__AQ_PNP_PROP("ETL", "Evertz Microsystems Ltd."),
	__AQ_PNP_PROP("ETS", "Electronic Trade Solutions Ltd"),
	__AQ_PNP_PROP("ETT", "E-Tech Inc"),
	__AQ_PNP_PROP("EUT", "Ericsson Mobile Networks B.V."),
	__AQ_PNP_PROP("EVE", "Advanced Micro Peripherals Ltd"),
	__AQ_PNP_PROP("EVI", "eviateg GmbH"),
	__AQ_PNP_PROP("EVP", "EverPro Technologies Company Limited"),
	__AQ_PNP_PROP("EVX", "Everex"),
	__AQ_PNP_PROP("EXA", "Exabyte"),
	__AQ_PNP_PROP("EXC", "Excession Audio"),
	__AQ_PNP_PROP("EXI", "Exide Electronics"),
	__AQ_PNP_PROP("EXN", "RGB Systems, Inc. dba Extron Electronics"),
	__AQ_PNP_PROP("EXP", "Data Export Corporation"),
	__AQ_PNP_PROP("EXR", "Explorer Inc."),
	__AQ_PNP_PROP("EXT", "Exatech Computadores & Servicos Ltda"),
	__AQ_PNP_PROP("EXX", "Exxact GmbH"),
	__AQ_PNP_PROP("EXY", "Exterity Ltd"),
	__AQ_PNP_PROP("EYE", "eyevis GmbH"),
	__AQ_PNP_PROP("EYF", "eyefactive Gmbh"),
	__AQ_PNP_PROP("EZE", "EzE Technologies"),
	__AQ_PNP_PROP("EZP", "Storm Technology"),
	__AQ_PNP_PROP("FAN", "Fantalooks Co., Ltd."),
	__AQ_PNP_PROP("FAR", "Farallon Computing"),
	__AQ_PNP_PROP("FBI", "Interface Corporation"),
	__AQ_PNP_PROP("FCB", "Furukawa Electric Company Ltd"),
	__AQ_PNP_PROP("FCG", "First International Computer Ltd"),
	__AQ_PNP_PROP("FCS", "Focus Enhancements, Inc."),
	__AQ_PNP_PROP("FDC", "Future Domain"),
	__AQ_PNP_PROP("FDD", "Forth Dimension Displays Ltd"),
	__AQ_PNP_PROP("FDI", "Future Designs, Inc."),
	__AQ_PNP_PROP("FDT", "Fujitsu Display Technologies Corp."),
	__AQ_PNP_PROP("FDX", "Findex, Inc."),
	__AQ_PNP_PROP("FEC", "FURUNO ELECTRIC CO., LTD."),
	__AQ_PNP_PROP("FEL", "Fellowes & Questec"),
	__AQ_PNP_PROP("FEN", "Fen Systems Ltd."),
	__AQ_PNP_PROP("FER", "Ferranti Int'L"),
	__AQ_PNP_PROP("FFC", "FUJIFILM Corporation"),
	__AQ_PNP_PROP("FFI", "Fairfield Industries"),
	__AQ_PNP_PROP("FGD", "Lisa Draexlmaier GmbH"),
	__AQ_PNP_PROP("FGL", "Fujitsu General Limited."),
	__AQ_PNP_PROP("FHL", "FHLP"),
	__AQ_PNP_PROP("FIC", "Formosa Industrial Computing Inc"),
	__AQ_PNP_PROP("FIL", "Forefront Int'l Ltd"),
	__AQ_PNP_PROP("FIN", "Finecom Co., Ltd."),
	__AQ_PNP_PROP("FIR", "Chaplet Systems Inc"),
	__AQ_PNP_PROP("FIS", "FLY-IT Simulators"),
	__AQ_PNP_PROP("FIT", "Feature Integration Technology Inc."),
	__AQ_PNP_PROP("FJC", "FCL COMPONENTS LIMITED"),
	__AQ_PNP_PROP("FJS", "Fujitsu Spain"),
	__AQ_PNP_PROP("FJT", "F.J. Tieman BV"),
	__AQ_PNP_PROP("FLE", "ADTI Media, Inc"),
	__AQ_PNP_PROP("FLI", "Faroudja Laboratories"),
	__AQ_PNP_PROP("FLY", "Butterfly Communications"),
	__AQ_PNP_PROP("FMA", "Fast Multimedia AG"),
	__AQ_PNP_PROP("FMC", "Ford Microelectronics Inc"),
	__AQ_PNP_PROP("FMI", "Fellowes, Inc."),
	__AQ_PNP_PROP("FML", "Fujitsu Microelect Ltd"),
	__AQ_PNP_PROP("FMZ", "Formoza-Altair"),
	__AQ_PNP_PROP("FNC", "Fanuc LTD"),
	__AQ_PNP_PROP("FNI", "Funai Electric Co., Ltd."),
	__AQ_PNP_PROP("FOA", "FOR-A Company Limited"),
	__AQ_PNP_PROP("FOK", "Fokus Technologies GmbH"),
	__AQ_PNP_PROP("FOS", "Foss Tecator"),
	__AQ_PNP_PROP("FOV", "FOVE INC"),
	__AQ_PNP_PROP("FOX", "HON HAI PRECISION IND.CO.,LTD."),
	__AQ_PNP_PROP("FPC", "Fingerprint Cards AB"),
	__AQ_PNP_PROP("FPE", "Fujitsu Peripherals Ltd"),
	__AQ_PNP_PROP("FPS", "Deltec Corporation"),
	__AQ_PNP_PROP("FPX", "Cirel Systemes"),
	__AQ_PNP_PROP("FRC", "Force Computers"),
	__AQ_PNP_PROP("FRD", "Freedom Scientific BLV"),
	__AQ_PNP_PROP("FRE", "Forvus Research Inc"),
	__AQ_PNP_PROP("FRI", "Fibernet Research Inc"),
	__AQ_PNP_PROP("FRO", "FARO Technologies"),
	__AQ_PNP_PROP("FRS", "South Mountain Technologies, LTD"),
	__AQ_PNP_PROP("FSC", "Future Systems Consulting KK"),
	__AQ_PNP_PROP("FSI", "Fore Systems Inc"),
	__AQ_PNP_PROP("FST", "Modesto PC Inc"),
	__AQ_PNP_PROP("FTC", "Futuretouch Corporation"),
	__AQ_PNP_PROP("FTE", "Frontline Test Equipment Inc."),
	__AQ_PNP_PROP("FTG", "FTG Data Systems"),
	__AQ_PNP_PROP("FTI", "FastPoint Technologies, Inc."),
	__AQ_PNP_PROP("FTL", "FUJITSU TEN LIMITED"),
	__AQ_PNP_PROP("FTN", "Fountain Technologies Inc"),
	__AQ_PNP_PROP("FTR", "Mediasonic"),
	__AQ_PNP_PROP("FTS", "FocalTech Systems Co., Ltd."),
	__AQ_PNP_PROP("FTW", "MindTribe Product Engineering, Inc."),
	__AQ_PNP_PROP("FUJ", "Fujitsu Ltd"),
	__AQ_PNP_PROP("FUL", "Fun Technology Innovation INC."),
	__AQ_PNP_PROP("FUN", "sisel muhendislik"),
	__AQ_PNP_PROP("FUS", "Fujitsu Siemens Computers GmbH"),
	__AQ_PNP_PROP("FVC", "First Virtual Corporation"),
	__AQ_PNP_PROP("FVX", "C-C-C Group Plc"),
	__AQ_PNP_PROP("FWA", "Attero Tech, LLC"),
	__AQ_PNP_PROP("FWR", "Flat Connections Inc"),
	__AQ_PNP_PROP("FXX", "Fuji Xerox"),
	__AQ_PNP_PROP("FZC", "Founder Group Shenzhen Co."),
	__AQ_PNP_PROP("FZI", "FZI Forschungszentrum Informatik"),
	__AQ_PNP_PROP("GAC", "GreenArrays, Inc."),
	__AQ_PNP_PROP("GAG", "Gage Applied Sciences Inc"),
	__AQ_PNP_PROP("GAL", "Galil Motion Control"),
	__AQ_PNP_PROP("GAU", "Gaudi Co., Ltd."),
	__AQ_PNP_PROP("GBT", "GIGA-BYTE TECHNOLOGY CO., LTD."),
	__AQ_PNP_PROP("GCC", "GCC Technologies Inc"),
	__AQ_PNP_PROP("GCI", "Gateway Comm. Inc"),
	__AQ_PNP_PROP("GCS", "Grey Cell Systems Ltd"),
	__AQ_PNP_PROP("GDC", "General Datacom"),
	__AQ_PNP_PROP("GDI", "G. Diehl ISDN GmbH"),
	__AQ_PNP_PROP("GDS", "GDS"),
	__AQ_PNP_PROP("GDT", "Vortex Computersysteme GmbH"),
	__AQ_PNP_PROP("GEC", "Gechic Corporation"),
	__AQ_PNP_PROP("GED", "General Dynamics C4 Systems"),
	__AQ_PNP_PROP("GEF", "GE Fanuc Embedded Systems"),
	__AQ_PNP_PROP("GEH", "Abaco Systems, Inc."),
	__AQ_PNP_PROP("GEM", "Gem Plus"),
	__AQ_PNP_PROP("GEN", "Genesys ATE Inc"),
	__AQ_PNP_PROP("GEO", "GEO Sense"),
	__AQ_PNP_PROP("GER", "GERMANEERS GmbH"),
	__AQ_PNP_PROP("GES", "GES Singapore Pte Ltd"),
	__AQ_PNP_PROP("GET", "Getac Technology Corporation"),
	__AQ_PNP_PROP("GFM", "GFMesstechnik GmbH"),
	__AQ_PNP_PROP("GFN", "Gefen Inc."),
	__AQ_PNP_PROP("GGL", "Google Inc."),
	__AQ_PNP_PROP("GGT", "G2TOUCH KOREA"),
	__AQ_PNP_PROP("GIC", "General Inst. Corporation"),
	__AQ_PNP_PROP("GIM", "Guillemont International"),
	__AQ_PNP_PROP("GIP", "GI Provision Ltd"),
	__AQ_PNP_PROP("GIS", "AT&T Global Info Solutions"),
	__AQ_PNP_PROP("GJN", "Grand Junction Networks"),
	__AQ_PNP_PROP("GLD", "Goldmund - Digital Audio SA"),
	__AQ_PNP_PROP("GLE", "AD electronics"),
	__AQ_PNP_PROP("GLM", "Genesys Logic"),
	__AQ_PNP_PROP("GLS", "Gadget Labs LLC"),
	__AQ_PNP_PROP("GMK", "GMK Electronic Design GmbH"),
	__AQ_PNP_PROP("GML", "General Information Systems"),
	__AQ_PNP_PROP("GMM", "GMM Research Inc"),
	__AQ_PNP_PROP("GMN", "GEMINI 2000 Ltd"),
	__AQ_PNP_PROP("GMX", "GMX Inc"),
	__AQ_PNP_PROP("GND", "Gennum Corporation"),
	__AQ_PNP_PROP("GNN", "GN Nettest Inc"),
	__AQ_PNP_PROP("GNZ", "Gunze Ltd"),
	__AQ_PNP_PROP("GOE", "GOEPEL electronic GmbH"),
	__AQ_PNP_PROP("GPR", "GoPro, Inc."),
	__AQ_PNP_PROP("GRA", "Graphica Computer"),
	__AQ_PNP_PROP("GRE", "GOLD RAIN ENTERPRISES CORP."),
	__AQ_PNP_PROP("GRH", "Granch Ltd"),
	__AQ_PNP_PROP("GRM", "Garmin International"),
	__AQ_PNP_PROP("GRV", "Advanced Gravis"),
	__AQ_PNP_PROP("GRY", "Robert Gray Company"),
	__AQ_PNP_PROP("GSB", "NIPPONDENCHI CO,.LTD"),
	__AQ_PNP_PROP("GSC", "General Standards Corporation"),
	__AQ_PNP_PROP("GSM", "LG Electronics"),
	__AQ_PNP_PROP("GSN", "Grandstream Networks, Inc."),
	__AQ_PNP_PROP("GST", "Graphic SystemTechnology"),
	__AQ_PNP_PROP("GSY", "Grossenbacher Systeme AG"),
	__AQ_PNP_PROP("GTC", "Graphtec Corporation"),
	__AQ_PNP_PROP("GTI", "Goldtouch"),
	__AQ_PNP_PROP("GTK", "G-Tech Corporation"),
	__AQ_PNP_PROP("GTM", "Garnet System Company Ltd"),
	__AQ_PNP_PROP("GTS", "Geotest Marvin Test Systems Inc"),
	__AQ_PNP_PROP("GTT", "General Touch Technology Co., Ltd."),
	__AQ_PNP_PROP("GUD", "Guntermann & Drunck GmbH"),
	__AQ_PNP_PROP("GUP", "GoUp Co.,Ltd"),
	__AQ_PNP_PROP("GUZ", "Guzik Technical Enterprises"),
	__AQ_PNP_PROP("GVC", "GVC Corporation"),
	__AQ_PNP_PROP("GVL", "Global Village Communication"),
	__AQ_PNP_PROP("GVS", "G.VISION"),
	__AQ_PNP_PROP("GWI", "GW Instruments"),
	__AQ_PNP_PROP("GWK", "Gateworks Corporation"),
	__AQ_PNP_PROP("GWY", "Gateway 2000"),
	__AQ_PNP_PROP("GXL", "Galaxy Microsystems Ltd."),
	__AQ_PNP_PROP("GZE", "GUNZE Limited"),
	__AQ_PNP_PROP("HAE", "Haider electronics"),
	__AQ_PNP_PROP("HAI", "Haivision Systems Inc."),
	__AQ_PNP_PROP("HAL", "Halberthal"),
	__AQ_PNP_PROP("HAN", "Hanchang System Corporation"),
	__AQ_PNP_PROP("HAR", "Harris Corporation"),
	__AQ_PNP_PROP("HAY", "Hayes Microcomputer Products Inc"),
	__AQ_PNP_PROP("HCA", "DAT"),
	__AQ_PNP_PROP("HCE", "Hitachi Consumer Electronics Co., Ltd"),
	__AQ_PNP_PROP("HCL", "HCL America Inc"),
	__AQ_PNP_PROP("HCM", "HCL Peripherals"),
	__AQ_PNP_PROP("HCP", "Hitachi Computer Products Inc"),
	__AQ_PNP_PROP("HCW", "Hauppauge Computer Works Inc"),
	__AQ_PNP_PROP("HDC", "HardCom Elektronik & Datateknik"),
	__AQ_PNP_PROP("HDI", "HD-INFO d.o.o."),
	__AQ_PNP_PROP("HDV", "Holografika kft."),
	__AQ_PNP_PROP("HEC", "Hisense Electric Co., Ltd."),
	__AQ_PNP_PROP("HEL", "Hitachi Micro Systems Europe Ltd"),
	__AQ_PNP_PROP("HER", "Ascom Business Systems"),
	__AQ_PNP_PROP("HET", "HETEC Datensysteme GmbH"),
	__AQ_PNP_PROP("HHC", "HIRAKAWA HEWTECH CORP."),
	__AQ_PNP_PROP("HHI", "Fraunhofer Heinrich-Hertz-Institute"),
	__AQ_PNP_PROP("HHT", "Hitevision Group"),
	__AQ_PNP_PROP("HIB", "Hibino Corporation"),
	__AQ_PNP_PROP("HIC", "Hitachi Information Technology Co., Ltd."),
	__AQ_PNP_PROP("HII", "Harman International Industries, Inc"),
	__AQ_PNP_PROP("HIK", "Hikom Co., Ltd."),
	__AQ_PNP_PROP("HIL", "Hilevel Technology"),
	__AQ_PNP_PROP("HIQ", "Kaohsiung Opto Electronics Americas, Inc."),
	__AQ_PNP_PROP("HIS", "Hope Industrial Systems, Inc."),
	__AQ_PNP_PROP("HIT", "Hitachi America Ltd"),
	__AQ_PNP_PROP("HJI", "Harris & Jeffries Inc"),
	__AQ_PNP_PROP("HKA", "HONKO MFG. CO., LTD."),
	__AQ_PNP_PROP("HKC", "HKC OVERSEAS LIMITED"),
	__AQ_PNP_PROP("HKG", "Josef Heim KG"),
	__AQ_PNP_PROP("HLG", "China Hualu Group Co., Ltd."),
	__AQ_PNP_PROP("HMC", "Hualon Microelectric Corporation"),
	__AQ_PNP_PROP("HMK", "hmk Daten-System-Technik BmbH"),
	__AQ_PNP_PROP("HMX", "HUMAX Co., Ltd."),
	__AQ_PNP_PROP("HNM", "HONOR Device Co., Ltd."),
	__AQ_PNP_PROP("HNS", "Hughes Network Systems"),
	__AQ_PNP_PROP("HOB", "HOB Electronic GmbH"),
	__AQ_PNP_PROP("HOE", "Hosiden Corporation"),
	__AQ_PNP_PROP("HOL", "Holoeye Photonics AG"),
	__AQ_PNP_PROP("HON", "Sonitronix"),
	__AQ_PNP_PROP("HPA", "Zytor Communications"),
	__AQ_PNP_PROP("HPC", "Hewlett-Packard Co."),
	__AQ_PNP_PROP("HPD", "Hewlett Packard"),
	__AQ_PNP_PROP("HPE", "Hewlett Packard Enterprise"),
	__AQ_PNP_PROP("HPI", "Headplay, Inc."),
	__AQ_PNP_PROP("HPK", "HAMAMATSU PHOTONICS K.K."),
	__AQ_PNP_PROP("HPN", "HP Inc."),
	__AQ_PNP_PROP("HPQ", "Hewlett-Packard Co."),
	__AQ_PNP_PROP("HPR", "H.P.R. Electronics GmbH"),
	__AQ_PNP_PROP("HRC", "Hercules"),
	__AQ_PNP_PROP("HRE", "Qingdao Haier Electronics Co., Ltd."),
	__AQ_PNP_PROP("HRI", "Hall Research"),
	__AQ_PNP_PROP("HRL", "Herolab GmbH"),
	__AQ_PNP_PROP("HRS", "Harris Semiconductor"),
	__AQ_PNP_PROP("HRT", "HERCULES"),
	__AQ_PNP_PROP("HSC", "Hagiwara Sys-Com Company Ltd"),
	__AQ_PNP_PROP("HSD", "HannStar Display Corp"),
	__AQ_PNP_PROP("HSM", "AT&T Microelectronics"),
	__AQ_PNP_PROP("HSN", "Hansung Co., Ltd"),
	__AQ_PNP_PROP("HSP", "HannStar Display Corp"),
	__AQ_PNP_PROP("HST", "Horsent Technology Co., Ltd."),
	__AQ_PNP_PROP("HTC", "Hitachi Ltd"),
	__AQ_PNP_PROP("HTI", "Hampshire Company, Inc."),
	__AQ_PNP_PROP("HTK", "Holtek Microelectronics Inc"),
	__AQ_PNP_PROP("HTL", "HTBLuVA Mödling"),
	__AQ_PNP_PROP("HTR", "Shenzhen ZhuoYi HengTong Computer Technology Limited"),
	__AQ_PNP_PROP("HTX", "Hitex Systementwicklung GmbH"),
	__AQ_PNP_PROP("HUB", "GAI-Tronics, A Hubbell Company"),
	__AQ_PNP_PROP("HUK", "Hoffmann + Krippner GmbH"),
	__AQ_PNP_PROP("HUM", "IMP Electronics Ltd."),
	__AQ_PNP_PROP("HVR", "HTC Corportation"),
	__AQ_PNP_PROP("HWA", "Harris Canada Inc"),
	__AQ_PNP_PROP("HWC", "DBA Hans Wedemeyer"),
	__AQ_PNP_PROP("HWD", "Highwater Designs Ltd"),
	__AQ_PNP_PROP("HWP", "Hewlett Packard"),
	__AQ_PNP_PROP("HWV", "Huawei Technologies Co., Inc."),
	__AQ_PNP_PROP("HXM", "Hexium Ltd."),
	__AQ_PNP_PROP("HYC", "Hypercope Gmbh Aachen"),
	__AQ_PNP_PROP("HYD", "Hydis Technologies.Co.,LTD"),
	__AQ_PNP_PROP("HYL", "Shanghai Chai Ming Huang Info&Tech Co, Ltd"),
	__AQ_PNP_PROP("HYO", "HYC CO., LTD."),
	__AQ_PNP_PROP("HYP", "Hyphen Ltd"),
	__AQ_PNP_PROP("HYR", "Hypertec Pty Ltd"),
	__AQ_PNP_PROP("HYT", "Heng Yu Technology (HK) Limited"),
	__AQ_PNP_PROP("HYV", "Hynix Semiconductor"),
	__AQ_PNP_PROP("IAD", "IAdea Corporation"),
	__AQ_PNP_PROP("IAF", "Institut f r angewandte Funksystemtechnik GmbH"),
	__AQ_PNP_PROP("IAI", "Integration Associates, Inc."),
	__AQ_PNP_PROP("IAT", "IAT Germany GmbH"),
	__AQ_PNP_PROP("IBC", "Integrated Business Systems"),
	__AQ_PNP_PROP("IBI", "INBINE.CO.LTD"),
	__AQ_PNP_PROP("IBM", "IBM Brasil"),
	__AQ_PNP_PROP("IBP", "IBP Instruments GmbH"),
	__AQ_PNP_PROP("IBR", "IBR GmbH"),
	__AQ_PNP_PROP("ICA", "ICA Inc"),
	__AQ_PNP_PROP("ICC", "BICC Data Networks Ltd"),
	__AQ_PNP_PROP("ICD", "ICD Inc"),
	__AQ_PNP_PROP("ICE", "IC Ensemble"),
	__AQ_PNP_PROP("ICI", "Infotek Communication Inc"),
	__AQ_PNP_PROP("ICM", "Intracom SA"),
	__AQ_PNP_PROP("ICN", "Sanyo Icon"),
	__AQ_PNP_PROP("ICO", "Intel Corp"),
	__AQ_PNP_PROP("ICP", "ICP Electronics, Inc./iEi Technology Corp."),
	__AQ_PNP_PROP("ICR", "Icron"),
	__AQ_PNP_PROP("ICS", "Integrated Circuit Systems"),
	__AQ_PNP_PROP("ICV", "Inside Contactless"),
	__AQ_PNP_PROP("ICX", "ICCC A/S"),
	__AQ_PNP_PROP("IDC", "International Datacasting Corporation"),
	__AQ_PNP_PROP("IDE", "IDE Associates"),
	__AQ_PNP_PROP("IDK", "IDK Corporation"),
	__AQ_PNP_PROP("IDN", "Idneo Technologies"),
	__AQ_PNP_PROP("IDO", "IDEO Product Development"),
	__AQ_PNP_PROP("IDP", "Integrated Device Technology, Inc."),
	__AQ_PNP_PROP("IDS", "Interdigital Sistemas de Informacao"),
	__AQ_PNP_PROP("IDT", "International Display Technology"),
	__AQ_PNP_PROP("IDX", "IDEXX Labs"),
	__AQ_PNP_PROP("IEC", "Interlace Engineering Corporation"),
	__AQ_PNP_PROP("IEE", "IEE"),
	__AQ_PNP_PROP("IEI", "Interlink Electronics"),
	__AQ_PNP_PROP("IFS", "In Focus Systems Inc"),
	__AQ_PNP_PROP("IFT", "Informtech"),
	__AQ_PNP_PROP("IFX", "Infineon Technologies AG"),
	__AQ_PNP_PROP("IFZ", "Infinite Z"),
	__AQ_PNP_PROP("IGC", "Intergate Pty Ltd"),
	__AQ_PNP_PROP("IGM", "IGM Communi"),
	__AQ_PNP_PROP("IHE", "InHand Electronics"),
	__AQ_PNP_PROP("IIC", "ISIC Innoscan Industrial Computers A/S"),
	__AQ_PNP_PROP("III", "Intelligent Instrumentation"),
	__AQ_PNP_PROP("IIN", "IINFRA Co., Ltd"),
	__AQ_PNP_PROP("IIT", "Informatik Information Technologies"),
	__AQ_PNP_PROP("IKE", "Ikegami Tsushinki Co. Ltd."),
	__AQ_PNP_PROP("IKS", "Ikos Systems Inc"),
	__AQ_PNP_PROP("ILC", "Image Logic Corporation"),
	__AQ_PNP_PROP("ILS", "Innotech Corporation"),
	__AQ_PNP_PROP("IMA", "Imagraph"),
	__AQ_PNP_PROP("IMB", "ART s.r.l."),
	__AQ_PNP_PROP("IMC", "IMC Networks"),
	__AQ_PNP_PROP("IMD", "ImasDe Canarias S.A."),
	__AQ_PNP_PROP("IME", "Imagraph"),
	__AQ_PNP_PROP("IMF", "Immersive Audio Technologies France"),
	__AQ_PNP_PROP("IMG", "IMAGENICS Co., Ltd."),
	__AQ_PNP_PROP("IMI", "International Microsystems Inc"),
	__AQ_PNP_PROP("IMM", "Immersion Corporation"),
	__AQ_PNP_PROP("IMN", "Impossible Production"),
	__AQ_PNP_PROP("IMP", "Impinj"),
	__AQ_PNP_PROP("IMT", "Inmax Technology Corporation"),
	__AQ_PNP_PROP("IMX", "arpara Technology Co., Ltd."),
	__AQ_PNP_PROP("INA", "Inventec Corporation"),
	__AQ_PNP_PROP("INC", "Home Row Inc"),
	__AQ_PNP_PROP("IND", "ILC"),
	__AQ_PNP_PROP("INE", "Inventec Electronics (M) Sdn. Bhd."),
	__AQ_PNP_PROP("INF", "Inframetrics Inc"),
	__AQ_PNP_PROP("ING", "Integraph Corporation"),
	__AQ_PNP_PROP("INI", "Initio Corporation"),
	__AQ_PNP_PROP("INK", "Indtek Co., Ltd."),
	__AQ_PNP_PROP("INL", "InnoLux Display Corporation"),
	__AQ_PNP_PROP("INM", "InnoMedia Inc"),
	__AQ_PNP_PROP("INN", "Innovent Systems, Inc."),
	__AQ_PNP_PROP("INO", "Innolab Pte Ltd"),
	__AQ_PNP_PROP("INP", "Interphase Corporation"),
	__AQ_PNP_PROP("INS", "Ines GmbH"),
	__AQ_PNP_PROP("INT", "Interphase Corporation"),
	__AQ_PNP_PROP("inu", "Inovatec S.p.A."),
	__AQ_PNP_PROP("INV", "Inviso, Inc."),
	__AQ_PNP_PROP("INX", "Communications Supply Corporation (A division of WESCO)"),
	__AQ_PNP_PROP("INZ", "Best Buy"),
	__AQ_PNP_PROP("IOA", "CRE Technology Corporation"),
	__AQ_PNP_PROP("IOC", "Guangxi Century Innovation Display Electronics Co., Ltd"),
	__AQ_PNP_PROP("IOD", "I-O Data Device Inc"),
	__AQ_PNP_PROP("IOM", "Iomega"),
	__AQ_PNP_PROP("ION", "Inside Out Networks"),
	__AQ_PNP_PROP("IOS", "i-O Display System"),
	__AQ_PNP_PROP("IOT", "I/OTech Inc"),
	__AQ_PNP_PROP("IPC", "IPC Corporation"),
	__AQ_PNP_PROP("IPD", "Industrial Products Design, Inc."),
	__AQ_PNP_PROP("IPI", "Intelligent Platform Management Interface (IPMI) forum (Intel, HP, NEC, Dell)"),
	__AQ_PNP_PROP("IPM", "IPM Industria Politecnica Meridionale SpA"),
	__AQ_PNP_PROP("IPN", "Performance Technologies"),
	__AQ_PNP_PROP("IPP", "IP Power Technologies GmbH"),
	__AQ_PNP_PROP("IPQ", "IP3 Technology Ltd."),
	__AQ_PNP_PROP("IPR", "Ithaca Peripherals"),
	__AQ_PNP_PROP("IPS", "IPS, Inc. (Intellectual Property Solutions, Inc.)"),
	__AQ_PNP_PROP("IPT", "International Power Technologies"),
	__AQ_PNP_PROP("IPW", "IPWireless, Inc"),
	__AQ_PNP_PROP("IQI", "IneoQuest Technologies, Inc"),
	__AQ_PNP_PROP("IQT", "IMAGEQUEST Co., Ltd"),
	__AQ_PNP_PROP("IRD", "Irdata"),
	__AQ_PNP_PROP("ISA", "Symbol Technologies"),
	__AQ_PNP_PROP("ISC", "Id3 Semiconductors"),
	__AQ_PNP_PROP("ISG", "Insignia Solutions Inc"),
	__AQ_PNP_PROP("ISI", "Interface Solutions"),
	__AQ_PNP_PROP("ISL", "Isolation Systems"),
	__AQ_PNP_PROP("ISM", "Image Stream Medical"),
	__AQ_PNP_PROP("ISP", "IntreSource Systems Pte Ltd"),
	__AQ_PNP_PROP("ISR", "INSIS Co., LTD."),
	__AQ_PNP_PROP("ISS", "ISS Inc"),
	__AQ_PNP_PROP("IST", "Intersolve Technologies"),
	__AQ_PNP_PROP("ISY", "International Integrated Systems,Inc.(IISI)"),
	__AQ_PNP_PROP("ITA", "Itausa Export North America"),
	__AQ_PNP_PROP("ITC", "Intercom Inc"),
	__AQ_PNP_PROP("ITD", "Internet Technology Corporation"),
	__AQ_PNP_PROP("ITE", "Integrated Tech Express Inc"),
	__AQ_PNP_PROP("ITI", "VanErum Group"),
	__AQ_PNP_PROP("ITK", "ITK Telekommunikation AG"),
	__AQ_PNP_PROP("ITL", "Inter-Tel"),
	__AQ_PNP_PROP("ITM", "ITM inc."),
	__AQ_PNP_PROP("ITN", "The NTI Group"),
	__AQ_PNP_PROP("ITP", "IT-PRO Consulting und Systemhaus GmbH"),
	__AQ_PNP_PROP("ITR", "Infotronic America, Inc."),
	__AQ_PNP_PROP("ITS", "IDTECH"),
	__AQ_PNP_PROP("ITT", "I&T Telecom."),
	__AQ_PNP_PROP("ITX", "integrated Technology Express Inc"),
	__AQ_PNP_PROP("IUC", "ICSL"),
	__AQ_PNP_PROP("IVI", "Intervoice Inc"),
	__AQ_PNP_PROP("IVM", "Iiyama North America"),
	__AQ_PNP_PROP("IVO", "InfoVision Optoelectronics (Kunshan) Co.,Ltd China"),
	__AQ_PNP_PROP("IVR", "Inlife-Handnet Co., Ltd."),
	__AQ_PNP_PROP("IVS", "Intevac Photonics Inc."),
	__AQ_PNP_PROP("IWR", "Icuiti Corporation"),
	__AQ_PNP_PROP("IWX", "Intelliworxx, Inc."),
	__AQ_PNP_PROP("IXD", "Intertex Data AB"),
	__AQ_PNP_PROP("IXN", "Shenzhen Inet Mobile Internet Technology Co., LTD"),
	__AQ_PNP_PROP("JAC", "Astec Inc"),
	__AQ_PNP_PROP("JAE", "Japan Aviation Electronics Industry, Limited"),
	__AQ_PNP_PROP("JAS", "Janz Automationssysteme AG"),
	__AQ_PNP_PROP("JAT", "Jaton Corporation"),
	__AQ_PNP_PROP("JAZ", "Carrera Computer Inc"),
	__AQ_PNP_PROP("JCE", "Jace Tech Inc"),
	__AQ_PNP_PROP("JDI", "Japan Display Inc."),
	__AQ_PNP_PROP("JDL", "Japan Digital Laboratory Co.,Ltd."),
	__AQ_PNP_PROP("JEM", "Japan E.M.Solutions Co., Ltd."),
	__AQ_PNP_PROP("JEN", "N-Vision"),
	__AQ_PNP_PROP("JET", "JET POWER TECHNOLOGY CO., LTD."),
	__AQ_PNP_PROP("JFX", "Jones Futurex Inc"),
	__AQ_PNP_PROP("JGD", "University College"),
	__AQ_PNP_PROP("JIC", "Jaeik Information & Communication Co., Ltd."),
	__AQ_PNP_PROP("JKC", "JVC KENWOOD Corporation"),
	__AQ_PNP_PROP("JLK", "UNIONMAN TECHNOLOGY CO., LTD"),
	__AQ_PNP_PROP("JMT", "Micro Technical Company Ltd"),
	__AQ_PNP_PROP("JPC", "JPC Technology Limited"),
	__AQ_PNP_PROP("JPW", "Wallis Hamilton Industries"),
	__AQ_PNP_PROP("JQE", "CNet Technical Inc"),
	__AQ_PNP_PROP("JSD", "JS DigiTech, Inc"),
	__AQ_PNP_PROP("JSI", "Jupiter Systems, Inc."),
	__AQ_PNP_PROP("JSK", "SANKEN ELECTRIC CO., LTD"),
	__AQ_PNP_PROP("JTS", "JS Motorsports"),
	__AQ_PNP_PROP("JTY", "jetway security micro,inc"),
	__AQ_PNP_PROP("JUK", "Janich & Klass Computertechnik GmbH"),
	__AQ_PNP_PROP("JUP", "Jupiter Systems"),
	__AQ_PNP_PROP("JVC", "JVC"),
	__AQ_PNP_PROP("JWD", "Video International Inc."),
	__AQ_PNP_PROP("JWL", "Jewell Instruments, LLC"),
	__AQ_PNP_PROP("JWS", "JWSpencer & Co."),
	__AQ_PNP_PROP("JWY", "Jetway Information Co., Ltd"),
	__AQ_PNP_PROP("KAR", "Karna"),
	__AQ_PNP_PROP("KBI", "Kidboard Inc"),
	__AQ_PNP_PROP("KBL", "Kobil Systems GmbH"),
	__AQ_PNP_PROP("KCD", "Chunichi Denshi Co.,LTD."),
	__AQ_PNP_PROP("KCL", "Keycorp Ltd"),
	__AQ_PNP_PROP("KDE", "KDE"),
	__AQ_PNP_PROP("KDK", "Kodiak Tech"),
	__AQ_PNP_PROP("KDM", "Korea Data Systems Co., Ltd."),
	__AQ_PNP_PROP("KDS", "KDS USA"),
	__AQ_PNP_PROP("KDT", "KDDI Technology Corporation"),
	__AQ_PNP_PROP("KEC", "Kyushu Electronics Systems Inc"),
	__AQ_PNP_PROP("KEM", "Kontron Embedded Modules GmbH"),
	__AQ_PNP_PROP("KES", "Kesa Corporation"),
	__AQ_PNP_PROP("KEU", "Kontron Europe GmbH"),
	__AQ_PNP_PROP("KEY", "Key Tech Inc"),
	__AQ_PNP_PROP("KFC", "SCD Tech"),
	__AQ_PNP_PROP("KFE", "Komatsu Forest"),
	__AQ_PNP_PROP("KFX", "Kofax Image Products"),
	__AQ_PNP_PROP("KGI", "Klipsch Group, Inc"),
	__AQ_PNP_PROP("KGL", "KEISOKU GIKEN Co.,Ltd."),
	__AQ_PNP_PROP("KGN", "KOGAN AUSTRALIA PTY LTD"),
	__AQ_PNP_PROP("KIO", "Kionix, Inc."),
	__AQ_PNP_PROP("KIS", "KiSS Technology A/S"),
	__AQ_PNP_PROP("KLT", "Colorlight"),
	__AQ_PNP_PROP("KMC", "Mitsumi Company Ltd"),
	__AQ_PNP_PROP("KME", "KIMIN Electronics Co., Ltd."),
	__AQ_PNP_PROP("KML", "Kensington Microware Ltd"),
	__AQ_PNP_PROP("KMR", "Kramer Electronics Ltd. International"),
	__AQ_PNP_PROP("KNC", "Konica corporation"),
	__AQ_PNP_PROP("KNX", "Nutech Marketing PTL"),
	__AQ_PNP_PROP("KOB", "Kobil Systems GmbH"),
	__AQ_PNP_PROP("KOD", "Eastman Kodak Company"),
	__AQ_PNP_PROP("KOE", "KOLTER ELECTRONIC"),
	__AQ_PNP_PROP("KOL", "Kollmorgen Motion Technologies Group"),
	__AQ_PNP_PROP("KOM", "Kontron GmbH"),
	__AQ_PNP_PROP("KOP", "Kopin Corporation"),
	__AQ_PNP_PROP("KOU", "KOUZIRO Co.,Ltd."),
	__AQ_PNP_PROP("KOW", "KOWA Company,LTD."),
	__AQ_PNP_PROP("KPC", "King Phoenix Company"),
	__AQ_PNP_PROP("KPT", "TPK Holding Co., Ltd"),
	__AQ_PNP_PROP("KRL", "Krell Industries Inc."),
	__AQ_PNP_PROP("KRM", "Kroma Telecom"),
	__AQ_PNP_PROP("KRY", "Kroy LLC"),
	__AQ_PNP_PROP("KSC", "Kinetic Systems Corporation"),
	__AQ_PNP_PROP("KSG", "KUPA China Shenzhen Micro Technology Co., Ltd. Gold Institute"),
	__AQ_PNP_PROP("KSL", "Karn Solutions Ltd."),
	__AQ_PNP_PROP("KSX", "King Tester Corporation"),
	__AQ_PNP_PROP("KTC", "Kingston Tech Corporation"),
	__AQ_PNP_PROP("KTD", "Takahata Electronics Co.,Ltd."),
	__AQ_PNP_PROP("KTE", "K-Tech"),
	__AQ_PNP_PROP("KTG", "Kayser-Threde GmbH"),
	__AQ_PNP_PROP("KTI", "Konica Technical Inc"),
	__AQ_PNP_PROP("KTK", "Key Tronic Corporation"),
	__AQ_PNP_PROP("KTN", "Katron Tech Inc"),
	__AQ_PNP_PROP("KTS", "Kyokko Communication System Co., Ltd."),
	__AQ_PNP_PROP("KUR", "Kurta Corporation"),
	__AQ_PNP_PROP("KVA", "Kvaser AB"),
	__AQ_PNP_PROP("KVX", "KeyView"),
	__AQ_PNP_PROP("KWD", "Kenwood Corporation"),
	__AQ_PNP_PROP("KYC", "Kyocera Corporation"),
	__AQ_PNP_PROP("KYE", "KYE Syst Corporation"),
	__AQ_PNP_PROP("KYK", "Samsung Electronics America Inc"),
	__AQ_PNP_PROP("KYN", "KEYENCE CORPORATION"),
	__AQ_PNP_PROP("KZI", "K-Zone International co. Ltd."),
	__AQ_PNP_PROP("KZN", "K-Zone International"),
	__AQ_PNP_PROP("LAB", "ACT Labs Ltd"),
	__AQ_PNP_PROP("LAC", "LaCie"),
	__AQ_PNP_PROP("LAF", "Microline"),
	__AQ_PNP_PROP("LAG", "Laguna Systems"),
	__AQ_PNP_PROP("LAN", "Sodeman Lancom Inc"),
	__AQ_PNP_PROP("LAS", "LASAT Comm. A/S"),
	__AQ_PNP_PROP("LAV", "Lava Computer MFG Inc"),
	__AQ_PNP_PROP("LBC", "LABAU Technology Corp."),
	__AQ_PNP_PROP("LBO", "Lubosoft"),
	__AQ_PNP_PROP("LCC", "LCI"),
	__AQ_PNP_PROP("LCD", "Toshiba Matsushita Display Technology Co., Ltd"),
	__AQ_PNP_PROP("LCE", "La Commande Electronique"),
	__AQ_PNP_PROP("LCI", "Lite-On Communication Inc"),
	__AQ_PNP_PROP("LCM", "Latitude Comm."),
	__AQ_PNP_PROP("LCN", "LEXICON"),
	__AQ_PNP_PROP("LCP", "Silent Power Electronics GmbH"),
	__AQ_PNP_PROP("LCS", "Longshine Electronics Company"),
	__AQ_PNP_PROP("LCT", "Labcal Technologies"),
	__AQ_PNP_PROP("LDN", "Laserdyne Technologies"),
	__AQ_PNP_PROP("LDT", "LogiDataTech Electronic GmbH"),
	__AQ_PNP_PROP("LEC", "Lectron Company Ltd"),
	__AQ_PNP_PROP("LED", "Long Engineering Design Inc"),
	__AQ_PNP_PROP("LEG", "Legerity, Inc"),
	__AQ_PNP_PROP("LEN", "Lenovo Group Limited"),
	__AQ_PNP_PROP("LEO", "First International Computer Inc"),
	__AQ_PNP_PROP("LEX", "Lexical Ltd"),
	__AQ_PNP_PROP("LGC", "Logic Ltd"),
	__AQ_PNP_PROP("LGD", "LG Display"),
	__AQ_PNP_PROP("LGI", "Logitech Inc"),
	__AQ_PNP_PROP("LGS", "LG Semicom Company Ltd"),
	__AQ_PNP_PROP("LGX", "Lasergraphics, Inc."),
	__AQ_PNP_PROP("LHA", "Lars Haagh ApS"),
	__AQ_PNP_PROP("LHC", "Beihai Century Joint Innovation Technology Co.,Ltd"),
	__AQ_PNP_PROP("LHE", "Lung Hwa Electronics Company Ltd"),
	__AQ_PNP_PROP("LHT", "Lighthouse Technologies Limited"),
	__AQ_PNP_PROP("LIN", "Lenovo Beijing Co. Ltd."),
	__AQ_PNP_PROP("LIP", "Linked IP GmbH"),
	__AQ_PNP_PROP("LIS", "Life is Style Inc."),
	__AQ_PNP_PROP("LIT", "Lithics Silicon Technology"),
	__AQ_PNP_PROP("LJX", "Datalogic Corporation"),
	__AQ_PNP_PROP("LKM", "Likom Technology Sdn. Bhd."),
	__AQ_PNP_PROP("LLL", "L-3 Communications"),
	__AQ_PNP_PROP("LLT", "LUMINO Licht Elektronik GmbH"),
	__AQ_PNP_PROP("LMG", "Lucent Technologies"),
	__AQ_PNP_PROP("LMI", "Lexmark Int'l Inc"),
	__AQ_PNP_PROP("LMP", "Leda Media Products"),
	__AQ_PNP_PROP("LMS", "Lumens Digital Optics Inc."),
	__AQ_PNP_PROP("LMT", "Laser Master"),
	__AQ_PNP_PROP("LNC", "Lincoln Technology Solutions"),
	__AQ_PNP_PROP("LND", "Land Computer Company Ltd"),
	__AQ_PNP_PROP("LNK", "Link Tech Inc"),
	__AQ_PNP_PROP("LNR", "Linear Systems Ltd."),
	__AQ_PNP_PROP("LNT", "LANETCO International"),
	__AQ_PNP_PROP("LNV", "Lenovo"),
	__AQ_PNP_PROP("LNX", "The Linux Foundation"),
	__AQ_PNP_PROP("LOC", "Locamation B.V."),
	__AQ_PNP_PROP("LOE", "Loewe Opta GmbH"),
	__AQ_PNP_PROP("LOG", "Logicode Technology Inc"),
	__AQ_PNP_PROP("LOL", "Litelogic Operations Ltd"),
	__AQ_PNP_PROP("LPE", "El-PUSK Co., Ltd."),
	__AQ_PNP_PROP("LPI", "Design Technology"),
	__AQ_PNP_PROP("LPL", "LG Philips"),
	__AQ_PNP_PROP("LSC", "LifeSize Communications"),
	__AQ_PNP_PROP("LSD", "Intersil Corporation"),
	__AQ_PNP_PROP("LSI", "Loughborough Sound Images"),
	__AQ_PNP_PROP("LSJ", "LSI Japan Company Ltd"),
	__AQ_PNP_PROP("LSL", "Logical Solutions"),
	__AQ_PNP_PROP("LSP", "Lightspace Technologies"),
	__AQ_PNP_PROP("LSY", "LSI Systems Inc"),
	__AQ_PNP_PROP("LTC", "Labtec Inc"),
	__AQ_PNP_PROP("LTI", "Jongshine Tech Inc"),
	__AQ_PNP_PROP("LTK", "Lucidity Technology Company Ltd"),
	__AQ_PNP_PROP("LTN", "Litronic Inc"),
	__AQ_PNP_PROP("LTS", "LTS Scale LLC"),
	__AQ_PNP_PROP("LTV", "Leitch Technology International Inc."),
	__AQ_PNP_PROP("LTW", "Lightware, Inc"),
	__AQ_PNP_PROP("LUC", "Lucent Technologies"),
	__AQ_PNP_PROP("LUM", "Lumagen, Inc."),
	__AQ_PNP_PROP("LUX", "Luxxell Research Inc"),
	__AQ_PNP_PROP("LVI", "LVI Low Vision International AB"),
	__AQ_PNP_PROP("LWC", "Labway Corporation"),
	__AQ_PNP_PROP("LWR", "Lightware Visual Engineering"),
	__AQ_PNP_PROP("LWW", "Lanier Worldwide"),
	__AQ_PNP_PROP("LXC", "LXCO Technologies AG"),
	__AQ_PNP_PROP("LXN", "Luxeon"),
	__AQ_PNP_PROP("LXS", "ELEA CardWare"),
	__AQ_PNP_PROP("LZX", "Lightwell Company Ltd"),
	__AQ_PNP_PROP("MAC", "MAC System Company Ltd"),
	__AQ_PNP_PROP("MAD", "Xedia Corporation"),
	__AQ_PNP_PROP("MAE", "Maestro Pty Ltd"),
	__AQ_PNP_PROP("MAG", "MAG InnoVision"),
	__AQ_PNP_PROP("MAI", "Mutoh America Inc"),
	__AQ_PNP_PROP("MAL", "Meridian Audio Ltd"),
	__AQ_PNP_PROP("MAN", "LGIC"),
	__AQ_PNP_PROP("MAS", "Mass Inc."),
	__AQ_PNP_PROP("MAT", "Panasonic Connect Co.,Ltd."),
	__AQ_PNP_PROP("MAX", "Rogen Tech Distribution Inc"),
	__AQ_PNP_PROP("MAY", "Maynard Electronics"),
	__AQ_PNP_PROP("MAZ", "MAZeT GmbH"),
	__AQ_PNP_PROP("MBC", "MBC"),
	__AQ_PNP_PROP("MBD", "Microbus PLC"),
	__AQ_PNP_PROP("MBM", "Marshall Electronics"),
	__AQ_PNP_PROP("MBV", "Moreton Bay"),
	__AQ_PNP_PROP("MCA", "American Nuclear Systems Inc"),
	__AQ_PNP_PROP("MCC", "Micro Industries"),
	__AQ_PNP_PROP("MCD", "McDATA Corporation"),
	__AQ_PNP_PROP("MCE", "Metz-Werke GmbH & Co KG"),
	__AQ_PNP_PROP("MCG", "Motorola Computer Group"),
	__AQ_PNP_PROP("MCI", "Micronics Computers"),
	__AQ_PNP_PROP("MCJ", "Medicaroid Corporation"),
	__AQ_PNP_PROP("MCL", "Motorola Communications Israel"),
	__AQ_PNP_PROP("MCM", "Metricom Inc"),
	__AQ_PNP_PROP("MCN", "Micron Electronics Inc"),
	__AQ_PNP_PROP("MCO", "Motion Computing Inc."),
	__AQ_PNP_PROP("MCP", "Magni Systems Inc"),
	__AQ_PNP_PROP("MCQ", "Mat's Computers"),
	__AQ_PNP_PROP("MCR", "Marina Communicaitons"),
	__AQ_PNP_PROP("MCS", "Micro Computer Systems"),
	__AQ_PNP_PROP("MCT", "Microtec"),
	__AQ_PNP_PROP("MCX", "Millson Custom Solutions Inc."),
	__AQ_PNP_PROP("MDA", "Media4 Inc"),
	__AQ_PNP_PROP("MDC", "Midori Electronics"),
	__AQ_PNP_PROP("MDD", "MODIS"),
	__AQ_PNP_PROP("MDF", "MILDEF AB"),
	__AQ_PNP_PROP("MDG", "Madge Networks"),
	__AQ_PNP_PROP("MDI", "Micro Design Inc"),
	__AQ_PNP_PROP("MDK", "Mediatek Corporation"),
	__AQ_PNP_PROP("MDO", "Panasonic"),
	__AQ_PNP_PROP("MDR", "Medar Inc"),
	__AQ_PNP_PROP("MDS", "Micro Display Systems Inc"),
	__AQ_PNP_PROP("MDT", "Magus Data Tech"),
	__AQ_PNP_PROP("MDV", "MET Development Inc"),
	__AQ_PNP_PROP("MDX", "MicroDatec GmbH"),
	__AQ_PNP_PROP("MDY", "Microdyne Inc"),
	__AQ_PNP_PROP("MEC", "Mega System Technologies Inc"),
	__AQ_PNP_PROP("MED", "Messeltronik Dresden GmbH"),
	__AQ_PNP_PROP("MEE", "Mitsubishi Electric Engineering Co., Ltd."),
	__AQ_PNP_PROP("MEG", "Abeam Tech Ltd."),
	__AQ_PNP_PROP("MEI", "Panasonic Industry Company"),
	__AQ_PNP_PROP("MEJ", "Mac-Eight Co., LTD."),
	__AQ_PNP_PROP("MEK", "Mediaedge Corporation"),
	__AQ_PNP_PROP("MEL", "Mitsubishi Electric Corporation"),
	__AQ_PNP_PROP("MEN", "MEN Mikroelectronik Nueruberg GmbH"),
	__AQ_PNP_PROP("MEP", "Meld Technology"),
	__AQ_PNP_PROP("MEQ", "Matelect Ltd."),
	__AQ_PNP_PROP("MET", "Metheus Corporation"),
	__AQ_PNP_PROP("MEU", "MPL AG, Elektronik-Unternehmen"),
	__AQ_PNP_PROP("MEX", "MSC Vertriebs GmbH"),
	__AQ_PNP_PROP("MFG", "MicroField Graphics Inc"),
	__AQ_PNP_PROP("MFI", "Micro Firmware"),
	__AQ_PNP_PROP("MFR", "MediaFire Corp."),
	__AQ_PNP_PROP("MGA", "Mega System Technologies, Inc."),
	__AQ_PNP_PROP("MGC", "Mentor Graphics Corporation"),
	__AQ_PNP_PROP("MGE", "Schneider Electric S.A."),
	__AQ_PNP_PROP("MGL", "M-G Technology Ltd"),
	__AQ_PNP_PROP("MGT", "Megatech R & D Company"),
	__AQ_PNP_PROP("MHQ", "Moxa Inc."),
	__AQ_PNP_PROP("MIC", "Micom Communications Inc"),
	__AQ_PNP_PROP("MID", "miro Displays"),
	__AQ_PNP_PROP("MII", "Mitec Inc"),
	__AQ_PNP_PROP("MIL", "Marconi Instruments Ltd"),
	__AQ_PNP_PROP("MIM", "Mimio – A Newell Rubbermaid Company"),
	__AQ_PNP_PROP("MIN", "Minicom Digital Signage"),
	__AQ_PNP_PROP("MIP", "micronpc.com"),
	__AQ_PNP_PROP("MIR", "Miro Computer Prod."),
	__AQ_PNP_PROP("MIS", "Modular Industrial Solutions Inc"),
	__AQ_PNP_PROP("MIT", "MCM Industrial Technology GmbH"),
	__AQ_PNP_PROP("MIV", "MicroImage Video Systems"),
	__AQ_PNP_PROP("MJI", "MARANTZ JAPAN, INC."),
	__AQ_PNP_PROP("MJS", "MJS Designs"),
	__AQ_PNP_PROP("MKC", "Media Tek Inc."),
	__AQ_PNP_PROP("MKS", "MK Seiko Co., Ltd."),
	__AQ_PNP_PROP("MKT", "MICROTEK Inc."),
	__AQ_PNP_PROP("MKV", "Trtheim Technology"),
	__AQ_PNP_PROP("MLC", "MILCOTS"),
	__AQ_PNP_PROP("MLD", "Deep Video Imaging Ltd"),
	__AQ_PNP_PROP("MLG", "Micrologica AG"),
	__AQ_PNP_PROP("MLI", "McIntosh Laboratory Inc."),
	__AQ_PNP_PROP("MLL", "Millogic Ltd."),
	__AQ_PNP_PROP("MLM", "Millennium Engineering Inc"),
	__AQ_PNP_PROP("MLN", "Mark Levinson"),
	__AQ_PNP_PROP("MLP", "Magic Leap"),
	__AQ_PNP_PROP("MLS", "Milestone EPE"),
	__AQ_PNP_PROP("MLT", "Wanlida Group Co., Ltd."),
	__AQ_PNP_PROP("MLX", "Mylex Corporation"),
	__AQ_PNP_PROP("MMA", "Micromedia AG"),
	__AQ_PNP_PROP("MMD", "Micromed Biotecnologia Ltd"),
	__AQ_PNP_PROP("MMF", "Minnesota Mining and Manufacturing"),
	__AQ_PNP_PROP("MMI", "Multimax"),
	__AQ_PNP_PROP("MMM", "Electronic Measurements"),
	__AQ_PNP_PROP("MMN", "MiniMan Inc"),
	__AQ_PNP_PROP("MMS", "MMS Electronics"),
	__AQ_PNP_PROP("MMT", "MIMO Monitors"),
	__AQ_PNP_PROP("MNC", "Mini Micro Methods Ltd"),
	__AQ_PNP_PROP("MNI", "Marseille, Inc."),
	__AQ_PNP_PROP("MNL", "Monorail Inc"),
	__AQ_PNP_PROP("MNP", "Microcom"),
	__AQ_PNP_PROP("MNS", "Maxnerva Technology Services Limited"),
	__AQ_PNP_PROP("MOC", "Matrix Orbital Corporation"),
	__AQ_PNP_PROP("MOD", "Modular Technology"),
	__AQ_PNP_PROP("MOK", "Moka International limited"),
	__AQ_PNP_PROP("MOM", "Momentum Data Systems"),
	__AQ_PNP_PROP("MOS", "Moses Corporation"),
	__AQ_PNP_PROP("MOT", "Motorola UDS"),
	__AQ_PNP_PROP("MPC", "M-Pact Inc"),
	__AQ_PNP_PROP("MPI", "Mediatrix Peripherals Inc"),
	__AQ_PNP_PROP("MPJ", "Microlab"),
	__AQ_PNP_PROP("MPL", "Maple Research Inst. Company Ltd"),
	__AQ_PNP_PROP("MPN", "Mainpine Limited"),
	__AQ_PNP_PROP("MPS", "mps Software GmbH"),
	__AQ_PNP_PROP("MPV", "Megapixel Visual Realty"),
	__AQ_PNP_PROP("MPX", "Micropix Technologies, Ltd."),
	__AQ_PNP_PROP("MQP", "MultiQ Products AB"),
	__AQ_PNP_PROP("MRA", "Miranda Technologies Inc"),
	__AQ_PNP_PROP("MRC", "Marconi Simulation & Ty-Coch Way Training"),
	__AQ_PNP_PROP("MRD", "MicroDisplay Corporation"),
	__AQ_PNP_PROP("MRG", "Nreal"),
	__AQ_PNP_PROP("MRK", "Maruko & Company Ltd"),
	__AQ_PNP_PROP("MRL", "Miratel"),
	__AQ_PNP_PROP("MRO", "Medikro Oy"),
	__AQ_PNP_PROP("MRT", "Merging Technologies"),
	__AQ_PNP_PROP("MSA", "Micro Systemation AB"),
	__AQ_PNP_PROP("MSC", "Mouse Systems Corporation"),
	__AQ_PNP_PROP("MSD", "Datenerfassungs- und Informationssysteme"),
	__AQ_PNP_PROP("MSF", "M-Systems Flash Disk Pioneers"),
	__AQ_PNP_PROP("MSG", "MSI GmbH"),
	__AQ_PNP_PROP("MSH", "Microsoft"),
	__AQ_PNP_PROP("MSI", "Microstep"),
	__AQ_PNP_PROP("MSK", "Megasoft Inc"),
	__AQ_PNP_PROP("MSL", "MicroSlate Inc."),
	__AQ_PNP_PROP("MSM", "Advanced Digital Systems"),
	__AQ_PNP_PROP("MSP", "Mistral Solutions [P] Ltd."),
	__AQ_PNP_PROP("MSR", "MASPRO DENKOH Corp."),
	__AQ_PNP_PROP("MST", "MS Telematica"),
	__AQ_PNP_PROP("MSU", "motorola"),
	__AQ_PNP_PROP("MSV", "Mosgi Corporation"),
	__AQ_PNP_PROP("MSX", "Micomsoft Co., Ltd."),
	__AQ_PNP_PROP("MSY", "MicroTouch Systems Inc"),
	__AQ_PNP_PROP("MTA", "Meta Watch Ltd"),
	__AQ_PNP_PROP("MTB", "Media Technologies Ltd."),
	__AQ_PNP_PROP("MTC", "Mars-Tech Corporation"),
	__AQ_PNP_PROP("MTD", "MindTech Display Co. Ltd"),
	__AQ_PNP_PROP("MTE", "MediaTec GmbH"),
	__AQ_PNP_PROP("MTH", "Micro-Tech Hearing Instruments"),
	__AQ_PNP_PROP("MTI", "MaxCom Technical Inc"),
	__AQ_PNP_PROP("MTJ", "MicroTechnica Co.,Ltd."),
	__AQ_PNP_PROP("MTK", "Microtek International Inc."),
	__AQ_PNP_PROP("MTL", "Mitel Corporation"),
	__AQ_PNP_PROP("MTM", "Motium"),
	__AQ_PNP_PROP("MTN", "Mtron Storage Technology Co., Ltd."),
	__AQ_PNP_PROP("MTR", "Mitron computer Inc"),
	__AQ_PNP_PROP("MTS", "Multi-Tech Systems"),
	__AQ_PNP_PROP("MTT", "Moore Threads Virtual Display"),
	__AQ_PNP_PROP("MTU", "Mark of the Unicorn Inc"),
	__AQ_PNP_PROP("MTX", "Matrox"),
	__AQ_PNP_PROP("MUD", "Multi-Dimension Institute"),
	__AQ_PNP_PROP("MUK", "Mainpine Limited"),
	__AQ_PNP_PROP("MVD", "Microvitec PLC"),
	__AQ_PNP_PROP("MVI", "Media Vision Inc"),
	__AQ_PNP_PROP("MVM", "SOBO VISION"),
	__AQ_PNP_PROP("MVN", "Meta Company"),
	__AQ_PNP_PROP("MVR", "MediCapture, Inc."),
	__AQ_PNP_PROP("MVS", "Microvision"),
	__AQ_PNP_PROP("MVX", "COM 1"),
	__AQ_PNP_PROP("MWI", "Multiwave Innovation Pte Ltd"),
	__AQ_PNP_PROP("MWR", "mware"),
	__AQ_PNP_PROP("MWY", "Microway Inc"),
	__AQ_PNP_PROP("MXD", "MaxData Computer GmbH & Co.KG"),
	__AQ_PNP_PROP("MXI", "Macronix Inc"),
	__AQ_PNP_PROP("MXL", "Hitachi Maxell, Ltd."),
	__AQ_PNP_PROP("MXM", "C&T Solution Inc."),
	__AQ_PNP_PROP("MXP", "Maxpeed Corporation"),
	__AQ_PNP_PROP("MXT", "Maxtech Corporation"),
	__AQ_PNP_PROP("MXV", "MaxVision Corporation"),
	__AQ_PNP_PROP("MYA", "Monydata"),
	__AQ_PNP_PROP("MYR", "Myriad Solutions Ltd"),
	__AQ_PNP_PROP("MYX", "Micronyx Inc"),
	__AQ_PNP_PROP("NAC", "Ncast Corporation"),
	__AQ_PNP_PROP("NAD", "NAD Electronics"),
	__AQ_PNP_PROP("NAF", "NAFASAE INDIA Pvt. Ltd"),
	__AQ_PNP_PROP("NAK", "Nakano Engineering Co.,Ltd."),
	__AQ_PNP_PROP("NAL", "Network Alchemy"),
	__AQ_PNP_PROP("NAT", "NaturalPoint Inc."),
	__AQ_PNP_PROP("NAV", "Navigation Corporation"),
	__AQ_PNP_PROP("NAX", "Naxos Tecnologia"),
	__AQ_PNP_PROP("NBL", "N*Able Technologies Inc"),
	__AQ_PNP_PROP("NBS", "National Key Lab. on ISN"),
	__AQ_PNP_PROP("NBT", "NingBo Bestwinning Technology CO., Ltd"),
	__AQ_PNP_PROP("NCA", "Nixdorf Company"),
	__AQ_PNP_PROP("NCC", "NCR Corporation"),
	__AQ_PNP_PROP("NCE", "Norcent Technology, Inc."),
	__AQ_PNP_PROP("NCI", "NewCom Inc"),
	__AQ_PNP_PROP("NCL", "NetComm Ltd"),
	__AQ_PNP_PROP("NCP", "Najing CEC Panda FPD Technology CO. ltd"),
	__AQ_PNP_PROP("NCR", "NCR Electronics"),
	__AQ_PNP_PROP("NCS", "Northgate Computer Systems"),
	__AQ_PNP_PROP("NCT", "NEC CustomTechnica, Ltd."),
	__AQ_PNP_PROP("NCV", "NewCoSemi (Beijing) Technology CO.,Ltd."),
	__AQ_PNP_PROP("NDC", "National DataComm Corporaiton"),
	__AQ_PNP_PROP("NDF", "NDF Special Light Products B.V."),
	__AQ_PNP_PROP("NDI", "National Display Systems"),
	__AQ_PNP_PROP("NDK", "Naitoh Densei CO., LTD."),
	__AQ_PNP_PROP("NDL", "Network Designers"),
	__AQ_PNP_PROP("NDS", "Nokia Data"),
	__AQ_PNP_PROP("NEC", "NEC Corporation"),
	__AQ_PNP_PROP("NEO", "NEO TELECOM CO.,LTD."),
	__AQ_PNP_PROP("NES", "INNES"),
	__AQ_PNP_PROP("NET", "Mettler Toledo"),
	__AQ_PNP_PROP("NEU", "NEUROTEC - EMPRESA DE PESQUISA E DESENVOLVIMENTO EM BIOMEDICINA"),
	__AQ_PNP_PROP("NEX", "Nexgen Mediatech Inc.,"),
	__AQ_PNP_PROP("NFC", "BTC Korea Co., Ltd"),
	__AQ_PNP_PROP("NFS", "Number Five Software"),
	__AQ_PNP_PROP("NGC", "Network General"),
	__AQ_PNP_PROP("NGS", "A D S Exports"),
	__AQ_PNP_PROP("NHC", "New H3C Technology Co., Ltd."),
	__AQ_PNP_PROP("NHT", "Vinci Labs"),
	__AQ_PNP_PROP("NIC", "National Instruments Corporation"),
	__AQ_PNP_PROP("NIS", "Nissei Electric Company"),
	__AQ_PNP_PROP("NIT", "Network Info Technology"),
	__AQ_PNP_PROP("NIX", "Seanix Technology Inc"),
	__AQ_PNP_PROP("NLC", "Next Level Communications"),
	__AQ_PNP_PROP("NME", "Navico, Inc."),
	__AQ_PNP_PROP("NMP", "Nokia Mobile Phones"),
	__AQ_PNP_PROP("NMS", "Natural Micro System"),
	__AQ_PNP_PROP("NMV", "NEC-Mitsubishi Electric Visual Systems Corporation"),
	__AQ_PNP_PROP("NMX", "Neomagic"),
	__AQ_PNP_PROP("NNC", "NNC"),
	__AQ_PNP_PROP("NOD", "3NOD Digital Technology Co. Ltd."),
	__AQ_PNP_PROP("NOE", "NordicEye AB"),
	__AQ_PNP_PROP("NOI", "North Invent A/S"),
	__AQ_PNP_PROP("NOK", "Nokia Display Products"),
	__AQ_PNP_PROP("NOR", "Norand Corporation"),
	__AQ_PNP_PROP("NOT", "Not Limited Inc"),
	__AQ_PNP_PROP("NPA", "Arvanics"),
	__AQ_PNP_PROP("NPI", "Network Peripherals Inc"),
	__AQ_PNP_PROP("NRI", "Noritake Itron Corporation"),
	__AQ_PNP_PROP("NRL", "U.S. Naval Research Lab"),
	__AQ_PNP_PROP("NRT", "Beijing Northern Radiantelecom Co."),
	__AQ_PNP_PROP("NRV", "Taugagreining hf"),
	__AQ_PNP_PROP("NSA", "NeuroSky, Inc."),
	__AQ_PNP_PROP("NSC", "National Semiconductor Corporation"),
	__AQ_PNP_PROP("NSI", "NISSEI ELECTRIC CO.,LTD"),
	__AQ_PNP_PROP("NSP", "Nspire System Inc."),
	__AQ_PNP_PROP("NSS", "Newport Systems Solutions"),
	__AQ_PNP_PROP("NST", "Network Security Technology Co"),
	__AQ_PNP_PROP("NTC", "NeoTech S.R.L"),
	__AQ_PNP_PROP("NTI", "New Tech Int'l Company"),
	__AQ_PNP_PROP("NTK", "NewTek"),
	__AQ_PNP_PROP("NTL", "National Transcomm. Ltd"),
	__AQ_PNP_PROP("NTN", "Nuvoton Technology Corporation"),
	__AQ_PNP_PROP("NTR", "N-trig Innovative Technologies, Inc."),
	__AQ_PNP_PROP("NTS", "Nits Technology Inc."),
	__AQ_PNP_PROP("NTT", "NTT Advanced Technology Corporation"),
	__AQ_PNP_PROP("NTW", "Networth Inc"),
	__AQ_PNP_PROP("NTX", "Netaccess Inc"),
	__AQ_PNP_PROP("NUG", "NU Technology, Inc."),
	__AQ_PNP_PROP("NUI", "NU Inc."),
	__AQ_PNP_PROP("NVC", "NetVision Corporation"),
	__AQ_PNP_PROP("NVD", "Nvidia"),
	__AQ_PNP_PROP("NVI", "NuVision US, Inc."),
	__AQ_PNP_PROP("NVL", "Novell Inc"),
	__AQ_PNP_PROP("NVO", "Netvio Ltd."),
	__AQ_PNP_PROP("NVR", "NOLO CO., LTD."),
	__AQ_PNP_PROP("NVT", "Navatek Engineering Corporation"),
	__AQ_PNP_PROP("NWC", "NW Computer Engineering"),
	__AQ_PNP_PROP("NWL", "Newline Interactive Inc."),
	__AQ_PNP_PROP("NWP", "NovaWeb Technologies Inc"),
	__AQ_PNP_PROP("NWS", "Newisys, Inc."),
	__AQ_PNP_PROP("NXC", "NextCom K.K."),
	__AQ_PNP_PROP("NXE", "Norxe AS"),
	__AQ_PNP_PROP("NXG", "Nexgen"),
	__AQ_PNP_PROP("NXP", "NXP Semiconductors bv."),
	__AQ_PNP_PROP("NXQ", "Nexiq Technologies, Inc."),
	__AQ_PNP_PROP("NXR", "Nextorage Corporation"),
	__AQ_PNP_PROP("NXS", "Technology Nexus Secure Open Systems AB"),
	__AQ_PNP_PROP("NXT", "NZXT (PNP same EDID)_"),
	__AQ_PNP_PROP("NYC", "Nakayo Relecommunications, Inc."),
	__AQ_PNP_PROP("OAK", "Oak Tech Inc"),
	__AQ_PNP_PROP("OAS", "Oasys Technology Company"),
	__AQ_PNP_PROP("OBS", "Optibase Technologies"),
	__AQ_PNP_PROP("OCD", "Macraigor Systems Inc"),
	__AQ_PNP_PROP("OCN", "Olfan"),
	__AQ_PNP_PROP("OCS", "Open Connect Solutions"),
	__AQ_PNP_PROP("ODM", "ODME Inc."),
	__AQ_PNP_PROP("ODR", "Odrac"),
	__AQ_PNP_PROP("OEC", "ORION ELECTRIC CO.,LTD"),
	__AQ_PNP_PROP("OEI", "Optum Engineering Inc."),
	__AQ_PNP_PROP("OFI", "Jiangxi Jinghao Optical Co., Ltd."),
	__AQ_PNP_PROP("OHW", "M-Labs Limited"),
	__AQ_PNP_PROP("OIC", "Option Industrial Computers"),
	__AQ_PNP_PROP("OIM", "Option International"),
	__AQ_PNP_PROP("OIN", "Option International"),
	__AQ_PNP_PROP("OKI", "OKI Electric Industrial Company Ltd"),
	__AQ_PNP_PROP("OLC", "Olicom A/S"),
	__AQ_PNP_PROP("OLD", "Olidata S.p.A."),
	__AQ_PNP_PROP("OLI", "Olivetti"),
	__AQ_PNP_PROP("OLT", "Olitec S.A."),
	__AQ_PNP_PROP("OLV", "Olitec S.A."),
	__AQ_PNP_PROP("OLY", "OLYMPUS CORPORATION"),
	__AQ_PNP_PROP("OMC", "OBJIX Multimedia Corporation"),
	__AQ_PNP_PROP("OMG", "RODE"),
	__AQ_PNP_PROP("OMN", "Omnitel"),
	__AQ_PNP_PROP("OMR", "Omron Corporation"),
	__AQ_PNP_PROP("ONE", "Oneac Corporation"),
	__AQ_PNP_PROP("ONK", "ONKYO Corporation"),
	__AQ_PNP_PROP("ONL", "OnLive, Inc"),
	__AQ_PNP_PROP("ONS", "On Systems Inc"),
	__AQ_PNP_PROP("ONW", "OPEN Networks Ltd"),
	__AQ_PNP_PROP("ONX", "SOMELEC Z.I. Du Vert Galanta"),
	__AQ_PNP_PROP("OOS", "OSRAM"),
	__AQ_PNP_PROP("OPC", "Opcode Inc"),
	__AQ_PNP_PROP("OPI", "D.N.S. Corporation"),
	__AQ_PNP_PROP("OPP", "OPPO Digital, Inc."),
	__AQ_PNP_PROP("OPT", "OPTi Inc"),
	__AQ_PNP_PROP("OPV", "Optivision Inc"),
	__AQ_PNP_PROP("OQI", "Oksori Company Ltd"),
	__AQ_PNP_PROP("ORG", "ORGA Kartensysteme GmbH"),
	__AQ_PNP_PROP("ORI", "OSR Open Systems Resources, Inc."),
	__AQ_PNP_PROP("ORN", "ORION ELECTRIC CO., LTD."),
	__AQ_PNP_PROP("OSA", "OSAKA Micro Computer, Inc."),
	__AQ_PNP_PROP("OSD", "Optical Systems Design Pty Ltd"),
	__AQ_PNP_PROP("OSI", "Open Stack, Inc."),
	__AQ_PNP_PROP("OSP", "OPTI-UPS Corporation"),
	__AQ_PNP_PROP("OSR", "Oksori Company Ltd"),
	__AQ_PNP_PROP("OTB", "outsidetheboxstuff.com"),
	__AQ_PNP_PROP("OTI", "Orchid Technology"),
	__AQ_PNP_PROP("OTK", "OmniTek"),
	__AQ_PNP_PROP("OTM", "Optoma Corporation"),
	__AQ_PNP_PROP("OTT", "OPTO22, Inc."),
	__AQ_PNP_PROP("OUK", "OUK Company Ltd"),
	__AQ_PNP_PROP("OVR", "Oculus VR, Inc."),
	__AQ_PNP_PROP("OWL", "Mediacom Technologies Pte Ltd"),
	__AQ_PNP_PROP("OXU", "Oxus Research S.A."),
	__AQ_PNP_PROP("OYO", "Shadow Systems"),
	__AQ_PNP_PROP("OZC", "OZ Corporation"),
	__AQ_PNP_PROP("OZD", "OZO Co.Ltd"),
	__AQ_PNP_PROP("OZO", "Tribe Computer Works Inc"),
	__AQ_PNP_PROP("PAC", "Pacific Avionics Corporation"),
	__AQ_PNP_PROP("PAD", "Promotion and Display Technology Ltd."),
	__AQ_PNP_PROP("PAE", "PreSonus Audio Electronics"),
	__AQ_PNP_PROP("PAK", "Many CNC System Co., Ltd."),
	__AQ_PNP_PROP("PAM", "Peter Antesberger Messtechnik"),
	__AQ_PNP_PROP("PAN", "The Panda Project"),
	__AQ_PNP_PROP("PAR", "Parallan Comp Inc"),
	__AQ_PNP_PROP("PBI", "Pitney Bowes"),
	__AQ_PNP_PROP("PBL", "Packard Bell Electronics"),
	__AQ_PNP_PROP("PBN", "Packard Bell NEC"),
	__AQ_PNP_PROP("PBV", "Pitney Bowes"),
	__AQ_PNP_PROP("PCA", "Philips BU Add On Card"),
	__AQ_PNP_PROP("PCB", "OCTAL S.A."),
	__AQ_PNP_PROP("PCC", "PowerCom Technology Company Ltd"),
	__AQ_PNP_PROP("PCG", "First Industrial Computer Inc"),
	__AQ_PNP_PROP("PCI", "Pioneer Computer Inc"),
	__AQ_PNP_PROP("PCK", "PCBANK21"),
	__AQ_PNP_PROP("PCL", "pentel.co.,ltd"),
	__AQ_PNP_PROP("PCM", "PCM Systems Corporation"),
	__AQ_PNP_PROP("PCO", "Performance Concepts Inc.,"),
	__AQ_PNP_PROP("PCP", "Procomp USA Inc"),
	__AQ_PNP_PROP("PCS", "TOSHIBA PERSONAL COMPUTER SYSTEM CORPRATION"),
	__AQ_PNP_PROP("PCT", "PC-Tel Inc"),
	__AQ_PNP_PROP("PCW", "Pacific CommWare Inc"),
	__AQ_PNP_PROP("PCX", "PC Xperten"),
	__AQ_PNP_PROP("PDM", "Psion Dacom Plc."),
	__AQ_PNP_PROP("PDN", "AT&T Paradyne"),
	__AQ_PNP_PROP("PDR", "Pure Data Inc"),
	__AQ_PNP_PROP("PDS", "PD Systems International Ltd"),
	__AQ_PNP_PROP("PDT", "PDTS - Prozessdatentechnik und Systeme"),
	__AQ_PNP_PROP("PDV", "Prodrive B.V."),
	__AQ_PNP_PROP("PEC", "POTRANS Electrical Corp."),
	__AQ_PNP_PROP("PEG", "Pegatron Corporation"),
	__AQ_PNP_PROP("PEI", "PEI Electronics Inc"),
	__AQ_PNP_PROP("PEL", "Primax Electric Ltd"),
	__AQ_PNP_PROP("PEN", "Interactive Computer Products Inc"),
	__AQ_PNP_PROP("PEP", "Peppercon AG"),
	__AQ_PNP_PROP("PER", "Perceptive Signal Technologies"),
	__AQ_PNP_PROP("PET", "Practical Electronic Tools"),
	__AQ_PNP_PROP("PFT", "Telia ProSoft AB"),
	__AQ_PNP_PROP("PGI", "PACSGEAR, Inc."),
	__AQ_PNP_PROP("PGM", "Paradigm Advanced Research Centre"),
	__AQ_PNP_PROP("PGP", "propagamma kommunikation"),
	__AQ_PNP_PROP("PGS", "Princeton Graphic Systems"),
	__AQ_PNP_PROP("PHC", "Pijnenburg Beheer N.V."),
	__AQ_PNP_PROP("PHE", "Philips Medical Systems Boeblingen GmbH"),
	__AQ_PNP_PROP("PHI", "Invalid Vendor Codename - PHI"),
	__AQ_PNP_PROP("PHL", "Philips Consumer Electronics Company"),
	__AQ_PNP_PROP("PHO", "Photonics Systems Inc."),
	__AQ_PNP_PROP("PHS", "Philips Communication Systems"),
	__AQ_PNP_PROP("PHY", "Phylon Communications"),
	__AQ_PNP_PROP("PIC", "Picturall Ltd."),
	__AQ_PNP_PROP("PIE", "Pacific Image Electronics Company Ltd"),
	__AQ_PNP_PROP("PIM", "Prism, LLC"),
	__AQ_PNP_PROP("PIO", "Pioneer Electronic Corporation"),
	__AQ_PNP_PROP("PIR", "Pico Technology Inc."),
	__AQ_PNP_PROP("PIS", "TECNART CO.,LTD."),
	__AQ_PNP_PROP("PIX", "Pixie Tech Inc"),
	__AQ_PNP_PROP("PJA", "Projecta"),
	__AQ_PNP_PROP("PJD", "Projectiondesign AS"),
	__AQ_PNP_PROP("PJT", "Pan Jit International Inc."),
	__AQ_PNP_PROP("PKA", "Acco UK Ltd."),
	__AQ_PNP_PROP("PLC", "Pro-Log Corporation"),
	__AQ_PNP_PROP("PLF", "Panasonic Avionics Corporation"),
	__AQ_PNP_PROP("PLM", "PROLINK Microsystems Corp."),
	__AQ_PNP_PROP("PLT", "PT Hartono Istana Teknologi"),
	__AQ_PNP_PROP("PLV", "PLUS Vision Corp."),
	__AQ_PNP_PROP("PLX", "Parallax Graphics"),
	__AQ_PNP_PROP("PLY", "Polycom Inc."),
	__AQ_PNP_PROP("PMC", "PMC Consumer Electronics Ltd"),
	__AQ_PNP_PROP("PMD", "TDK USA Corporation"),
	__AQ_PNP_PROP("PMM", "Point Multimedia System"),
	__AQ_PNP_PROP("PMS", "Pabian Embedded Systems"),
	__AQ_PNP_PROP("PMT", "Promate Electronic Co., Ltd."),
	__AQ_PNP_PROP("PMX", "Photomatrix"),
	__AQ_PNP_PROP("PNG", "Microsoft"),
	__AQ_PNP_PROP("PNL", "Panelview, Inc."),
	__AQ_PNP_PROP("PNP", "Microsoft"),
	__AQ_PNP_PROP("PNR", "Planar Systems, Inc."),
	__AQ_PNP_PROP("PNS", "PanaScope"),
	__AQ_PNP_PROP("PNT", "HOYA Corporation PENTAX Lifecare Division"),
	__AQ_PNP_PROP("PNX", "Phoenix Technologies, Ltd."),
	__AQ_PNP_PROP("POL", "PolyComp (PTY) Ltd."),
	__AQ_PNP_PROP("PON", "Perpetual Technologies, LLC"),
	__AQ_PNP_PROP("POR", "Portalis LC"),
	__AQ_PNP_PROP("POS", "Positivo Tecnologia S.A."),
	__AQ_PNP_PROP("POT", "Parrot"),
	__AQ_PNP_PROP("PPC", "Phoenixtec Power Company Ltd"),
	__AQ_PNP_PROP("PPD", "MEPhI"),
	__AQ_PNP_PROP("PPI", "Practical Peripherals"),
	__AQ_PNP_PROP("PPM", "Clinton Electronics Corp."),
	__AQ_PNP_PROP("PPP", "Purup Prepress AS"),
	__AQ_PNP_PROP("PPR", "PicPro"),
	__AQ_PNP_PROP("PPX", "Perceptive Pixel Inc."),
	__AQ_PNP_PROP("PQI", "Pixel Qi"),
	__AQ_PNP_PROP("PRA", "PRO/AUTOMATION"),
	__AQ_PNP_PROP("PRC", "PerComm"),
	__AQ_PNP_PROP("PRD", "Praim S.R.L."),
	__AQ_PNP_PROP("PRF", "Schneider Electric Japan Holdings, Ltd."),
	__AQ_PNP_PROP("PRG", "The Phoenix Research Group Inc"),
	__AQ_PNP_PROP("PRI", "Priva Hortimation BV"),
	__AQ_PNP_PROP("PRM", "Prometheus"),
	__AQ_PNP_PROP("PRO", "Proteon"),
	__AQ_PNP_PROP("PRP", "UEFI Forum"),
	__AQ_PNP_PROP("PRS", "Leutron Vision"),
	__AQ_PNP_PROP("PRT", "Parade Technologies, Ltd."),
	__AQ_PNP_PROP("PRX", "Proxima Corporation"),
	__AQ_PNP_PROP("PSA", "Advanced Signal Processing Technologies"),
	__AQ_PNP_PROP("PSC", "Philips Semiconductors"),
	__AQ_PNP_PROP("PSD", "Peus-Systems GmbH"),
	__AQ_PNP_PROP("PSE", "Practical Solutions Pte., Ltd."),
	__AQ_PNP_PROP("PSI", "PSI-Perceptive Solutions Inc"),
	__AQ_PNP_PROP("PSL", "Perle Systems Limited"),
	__AQ_PNP_PROP("PSM", "Prosum"),
	__AQ_PNP_PROP("PST", "Global Data SA"),
	__AQ_PNP_PROP("PSY", "Prodea Systems Inc."),
	__AQ_PNP_PROP("PTA", "PAR Tech Inc."),
	__AQ_PNP_PROP("PTC", "PS Technology Corporation"),
	__AQ_PNP_PROP("PTG", "Cipher Systems Inc"),
	__AQ_PNP_PROP("PTH", "Pathlight Technology Inc"),
	__AQ_PNP_PROP("PTI", "Promise Technology Inc"),
	__AQ_PNP_PROP("PTL", "Pantel Inc"),
	__AQ_PNP_PROP("PTS", "Plain Tree Systems Inc"),
	__AQ_PNP_PROP("PTW", "Invalid Vendor Codename - PTW"),
	__AQ_PNP_PROP("PTX", "Printronix LLC"),
	__AQ_PNP_PROP("PUL", "Pulse-Eight Ltd"),
	__AQ_PNP_PROP("PVC", "Invalid Vendor Codename - PVC"),
	__AQ_PNP_PROP("PVG", "Proview Global Co., Ltd"),
	__AQ_PNP_PROP("PVI", "Prime view international Co., Ltd"),
	__AQ_PNP_PROP("PVM", "Penta Studiotechnik GmbH"),
	__AQ_PNP_PROP("PVN", "Pixel Vision"),
	__AQ_PNP_PROP("PVP", "Klos Technologies, Inc."),
	__AQ_PNP_PROP("PVR", "Pimax Tech. CO., LTD"),
	__AQ_PNP_PROP("PXC", "Phoenix Contact"),
	__AQ_PNP_PROP("PXE", "PIXELA CORPORATION"),
	__AQ_PNP_PROP("PXL", "The Moving Pixel Company"),
	__AQ_PNP_PROP("PXM", "Proxim Inc"),
	__AQ_PNP_PROP("PXN", "PixelNext Inc"),
	__AQ_PNP_PROP("PXO", "Pixio USA"),
	__AQ_PNP_PROP("QCC", "QuakeCom Company Ltd"),
	__AQ_PNP_PROP("QCH", "Metronics Inc"),
	__AQ_PNP_PROP("QCI", "Quanta Computer Inc"),
	__AQ_PNP_PROP("QCK", "Quick Corporation"),
	__AQ_PNP_PROP("QCL", "Quadrant Components Inc"),
	__AQ_PNP_PROP("QCP", "Qualcomm Inc"),
	__AQ_PNP_PROP("QDI", "Quantum Data Incorporated"),
	__AQ_PNP_PROP("QDL", "QD Laser, Inc."),
	__AQ_PNP_PROP("QDM", "Quadram"),
	__AQ_PNP_PROP("QDS", "Quanta Display Inc."),
	__AQ_PNP_PROP("QFF", "Padix Co., Inc."),
	__AQ_PNP_PROP("QFI", "Quickflex, Inc"),
	__AQ_PNP_PROP("QLC", "Q-Logic"),
	__AQ_PNP_PROP("QQQ", "Chuomusen Co., Ltd."),
	__AQ_PNP_PROP("QSC", "QSC, LLC"),
	__AQ_PNP_PROP("QSI", "Quantum Solutions, Inc."),
	__AQ_PNP_PROP("QTD", "Quantum 3D Inc"),
	__AQ_PNP_PROP("QTH", "Questech Ltd"),
	__AQ_PNP_PROP("QTI", "Quicknet Technologies Inc"),
	__AQ_PNP_PROP("QTM", "Quantum"),
	__AQ_PNP_PROP("QTR", "Qtronix Corporation"),
	__AQ_PNP_PROP("QUA", "Quatographic AG"),
	__AQ_PNP_PROP("QUE", "Questra Consulting"),
	__AQ_PNP_PROP("QVU", "Quartics"),
	__AQ_PNP_PROP("RAC", "Racore Computer Products Inc"),
	__AQ_PNP_PROP("RAD", "Radisys Corporation"),
	__AQ_PNP_PROP("RAI", "Rockwell Automation/Intecolor"),
	__AQ_PNP_PROP("RAN", "Rancho Tech Inc"),
	__AQ_PNP_PROP("RAR", "Raritan, Inc."),
	__AQ_PNP_PROP("RAS", "RAScom Inc"),
	__AQ_PNP_PROP("RAT", "Rent-A-Tech"),
	__AQ_PNP_PROP("RAY", "Raylar Design, Inc."),
	__AQ_PNP_PROP("RCE", "Parc d'Activite des Bellevues"),
	__AQ_PNP_PROP("RCH", "Reach Technology Inc"),
	__AQ_PNP_PROP("RCI", "RC International"),
	__AQ_PNP_PROP("RCN", "Radio Consult SRL"),
	__AQ_PNP_PROP("RCO", "Rockwell Collins"),
	__AQ_PNP_PROP("RDI", "Rainbow Displays, Inc."),
	__AQ_PNP_PROP("RDL", "Riedel Communications Canada Inc."),
	__AQ_PNP_PROP("RDM", "Tremon Enterprises Company Ltd"),
	__AQ_PNP_PROP("RDN", "RADIODATA GmbH"),
	__AQ_PNP_PROP("RDS", "Radius Inc"),
	__AQ_PNP_PROP("REA", "Real D"),
	__AQ_PNP_PROP("REC", "ReCom"),
	__AQ_PNP_PROP("RED", "Research Electronics Development Inc"),
	__AQ_PNP_PROP("REF", "Reflectivity, Inc."),
	__AQ_PNP_PROP("REH", "Rehan Electronics Ltd."),
	__AQ_PNP_PROP("REL", "Reliance Electric Ind Corporation"),
	__AQ_PNP_PROP("REM", "SCI Systems Inc."),
	__AQ_PNP_PROP("REN", "Renesas Technology Corp."),
	__AQ_PNP_PROP("RES", "ResMed Pty Ltd"),
	__AQ_PNP_PROP("RET", "Resonance Technology, Inc."),
	__AQ_PNP_PROP("REV", "Revolution Display, Inc."),
	__AQ_PNP_PROP("REX", "RATOC Systems, Inc."),
	__AQ_PNP_PROP("RFI", "RAFI GmbH & Co. KG"),
	__AQ_PNP_PROP("RFX", "Redfox Technologies Inc."),
	__AQ_PNP_PROP("RGB", "RGB Spectrum"),
	__AQ_PNP_PROP("RGL", "Robertson Geologging Ltd"),
	__AQ_PNP_PROP("RHD", "RightHand Technologies"),
	__AQ_PNP_PROP("RHM", "Rohm Company Ltd"),
	__AQ_PNP_PROP("RHT", "Red Hat, Inc."),
	__AQ_PNP_PROP("RIC", "RICOH COMPANY, LTD."),
	__AQ_PNP_PROP("RII", "Racal Interlan Inc"),
	__AQ_PNP_PROP("RIO", "Rios Systems Company Ltd"),
	__AQ_PNP_PROP("RIT", "Ritech Inc"),
	__AQ_PNP_PROP("RIV", "Rivulet Communications"),
	__AQ_PNP_PROP("RJA", "Roland Corporation"),
	__AQ_PNP_PROP("RJS", "Advanced Engineering"),
	__AQ_PNP_PROP("RKC", "Reakin Technolohy Corporation"),
	__AQ_PNP_PROP("RLD", "MEPCO"),
	__AQ_PNP_PROP("RLN", "RadioLAN Inc"),
	__AQ_PNP_PROP("RMC", "Raritan Computer, Inc"),
	__AQ_PNP_PROP("RMP", "Research Machines"),
	__AQ_PNP_PROP("RMS", "Shenzhen Ramos Digital Technology Co., Ltd"),
	__AQ_PNP_PROP("RMT", "Roper Mobile"),
	__AQ_PNP_PROP("RNB", "Rainbow Technologies"),
	__AQ_PNP_PROP("RNL", "Reonel Oy"),
	__AQ_PNP_PROP("ROB", "Robust Electronics GmbH"),
	__AQ_PNP_PROP("ROH", "Rohm Co., Ltd."),
	__AQ_PNP_PROP("ROK", "Rockwell International"),
	__AQ_PNP_PROP("ROP", "Roper International Ltd"),
	__AQ_PNP_PROP("ROS", "Rohde & Schwarz"),
	__AQ_PNP_PROP("RPI", "RoomPro Technologies"),
	__AQ_PNP_PROP("RPL", "Raspberry PI"),
	__AQ_PNP_PROP("RPT", "R.P.T.Intergroups"),
	__AQ_PNP_PROP("RRI", "Radicom Research Inc"),
	__AQ_PNP_PROP("RRO", "AVARRO"),
	__AQ_PNP_PROP("RSC", "PhotoTelesis"),
	__AQ_PNP_PROP("RSH", "ADC-Centre"),
	__AQ_PNP_PROP("RSI", "Rampage Systems Inc"),
	__AQ_PNP_PROP("RSN", "Radiospire Networks, Inc."),
	__AQ_PNP_PROP("RSQ", "R Squared"),
	__AQ_PNP_PROP("RSR", "Zhong Shan City Richsound Electronic Industrial Ltd."),
	__AQ_PNP_PROP("RSS", "Rockwell Semiconductor Systems"),
	__AQ_PNP_PROP("RSV", "Ross Video Ltd"),
	__AQ_PNP_PROP("RSX", "Rapid Tech Corporation"),
	__AQ_PNP_PROP("RTC", "Relia Technologies"),
	__AQ_PNP_PROP("RTI", "Rancho Tech Inc"),
	__AQ_PNP_PROP("RTK", "Invalid Vendor Codename - RTK"),
	__AQ_PNP_PROP("RTL", "Realtek Semiconductor Company Ltd"),
	__AQ_PNP_PROP("RTS", "Raintree Systems"),
	__AQ_PNP_PROP("RUN", "RUNCO International"),
	__AQ_PNP_PROP("RUP", "Ups Manufactoring s.r.l."),
	__AQ_PNP_PROP("RVC", "RSI Systems Inc"),
	__AQ_PNP_PROP("RVI", "Realvision Inc"),
	__AQ_PNP_PROP("RVL", "Reveal Computer Prod"),
	__AQ_PNP_PROP("RWC", "Red Wing Corporation"),
	__AQ_PNP_PROP("RXT", "Tectona SoftSolutions (P) Ltd.,"),
	__AQ_PNP_PROP("RZR", "Razer Taiwan Co. Ltd."),
	__AQ_PNP_PROP("RZS", "Rozsnyó, s.r.o."),
	__AQ_PNP_PROP("SAA", "Sanritz Automation Co.,Ltd."),
	__AQ_PNP_PROP("SAE", "Saab Aerotech"),
	__AQ_PNP_PROP("SAG", "Sedlbauer"),
	__AQ_PNP_PROP("SAI", "Sage Inc"),
	__AQ_PNP_PROP("SAK", "Saitek Ltd"),
	__AQ_PNP_PROP("SAM", "Samsung Electric Company"),
	__AQ_PNP_PROP("SAN", "Sanyo Electric Co.,Ltd."),
	__AQ_PNP_PROP("SAS", "Stores Automated Systems Inc"),
	__AQ_PNP_PROP("SAT", "Shuttle Tech"),
	__AQ_PNP_PROP("SBC", "Shanghai Bell Telephone Equip Mfg Co"),
	__AQ_PNP_PROP("SBD", "Softbed - Consulting & Development Ltd"),
	__AQ_PNP_PROP("SBI", "SMART Technologies Inc."),
	__AQ_PNP_PROP("SBS", "SBS-or Industrial Computers GmbH"),
	__AQ_PNP_PROP("SBT", "Senseboard Technologies AB"),
	__AQ_PNP_PROP("SCA", "Schneider Consumer Group"),
	__AQ_PNP_PROP("SCB", "SeeCubic B.V."),
	__AQ_PNP_PROP("SCC", "SORD Computer Corporation"),
	__AQ_PNP_PROP("SCD", "Sanyo Electric Company Ltd"),
	__AQ_PNP_PROP("SCE", "Sun Corporation"),
	__AQ_PNP_PROP("SCG", "Seco S.p.A."),
	__AQ_PNP_PROP("SCH", "Schlumberger Cards"),
	__AQ_PNP_PROP("SCI", "System Craft"),
	__AQ_PNP_PROP("SCL", "Sigmacom Co., Ltd."),
	__AQ_PNP_PROP("SCM", "SCM Microsystems Inc"),
	__AQ_PNP_PROP("SCN", "Scanport, Inc."),
	__AQ_PNP_PROP("SCO", "SORCUS Computer GmbH"),
	__AQ_PNP_PROP("SCP", "Scriptel Corporation"),
	__AQ_PNP_PROP("SCR", "Systran Corporation"),
	__AQ_PNP_PROP("SCS", "Nanomach Anstalt"),
	__AQ_PNP_PROP("SCT", "Smart Card Technology"),
	__AQ_PNP_PROP("SCX", "Socionext Inc."),
	__AQ_PNP_PROP("SDA", "SAT (Societe Anonyme)"),
	__AQ_PNP_PROP("SDC", "Samsung Display Corp."),
	__AQ_PNP_PROP("SDD", "Intrada-SDD Ltd"),
	__AQ_PNP_PROP("SDE", "Sherwood Digital Electronics Corporation"),
	__AQ_PNP_PROP("SDF", "SODIFF E&T CO., Ltd."),
	__AQ_PNP_PROP("SDH", "Communications Specialies, Inc."),
	__AQ_PNP_PROP("SDI", "Samtron Displays Inc"),
	__AQ_PNP_PROP("SDK", "SAIT-Devlonics"),
	__AQ_PNP_PROP("SDR", "SDR Systems"),
	__AQ_PNP_PROP("SDS", "SunRiver Data System"),
	__AQ_PNP_PROP("SDT", "Siemens AG"),
	__AQ_PNP_PROP("SDX", "SDX Business Systems Ltd"),
	__AQ_PNP_PROP("SEA", "Seanix Technology Inc."),
	__AQ_PNP_PROP("SEB", "system elektronik GmbH"),
	__AQ_PNP_PROP("SEC", "Seiko Epson Corporation"),
	__AQ_PNP_PROP("SEE", "SeeColor Corporation"),
	__AQ_PNP_PROP("SEG", "Invalid Vendor Codename - SEG"),
	__AQ_PNP_PROP("SEI", "Seitz & Associates Inc"),
	__AQ_PNP_PROP("SEL", "Way2Call Communications"),
	__AQ_PNP_PROP("SEM", "Samsung Electronics Company Ltd"),
	__AQ_PNP_PROP("SEN", "Sencore"),
	__AQ_PNP_PROP("SEO", "SEOS Ltd"),
	__AQ_PNP_PROP("SEP", "SEP Eletronica Ltda."),
	__AQ_PNP_PROP("SER", "Sony Ericsson Mobile Communications Inc."),
	__AQ_PNP_PROP("SES", "Session Control LLC"),
	__AQ_PNP_PROP("SET", "SendTek Corporation"),
	__AQ_PNP_PROP("SFL", "Shiftall Inc."),
	__AQ_PNP_PROP("SFM", "TORNADO Company"),
	__AQ_PNP_PROP("SFT", "Mikroforum Ring 3"),
	__AQ_PNP_PROP("SGC", "Spectragraphics Corporation"),
	__AQ_PNP_PROP("SGD", "Sigma Designs, Inc."),
	__AQ_PNP_PROP("SGE", "Kansai Electric Company Ltd"),
	__AQ_PNP_PROP("SGI", "Scan Group Ltd"),
	__AQ_PNP_PROP("SGL", "Super Gate Technology Company Ltd"),
	__AQ_PNP_PROP("SGM", "SAGEM"),
	__AQ_PNP_PROP("SGN", "Shenzhen Soogeen Electronics Co., LTD."),
	__AQ_PNP_PROP("SGO", "Logos Design A/S"),
	__AQ_PNP_PROP("SGT", "Stargate Technology"),
	__AQ_PNP_PROP("SGW", "Shanghai Guowei Science and Technology Co., Ltd."),
	__AQ_PNP_PROP("SGX", "Silicon Graphics Inc"),
	__AQ_PNP_PROP("SGZ", "Systec Computer GmbH"),
	__AQ_PNP_PROP("SHC", "ShibaSoku Co., Ltd."),
	__AQ_PNP_PROP("SHG", "Soft & Hardware development Goldammer GmbH"),
	__AQ_PNP_PROP("SHI", "Jiangsu Shinco Electronic Group Co., Ltd"),
	__AQ_PNP_PROP("SHP", "Sharp Corporation"),
	__AQ_PNP_PROP("SHR", "Digital Discovery"),
	__AQ_PNP_PROP("SHT", "Shin Ho Tech"),
	__AQ_PNP_PROP("SHU", "Shure Inc."),
	__AQ_PNP_PROP("SIA", "SIEMENS AG"),
	__AQ_PNP_PROP("SIB", "Sanyo Electric Company Ltd"),
	__AQ_PNP_PROP("SIC", "Sysmate Corporation"),
	__AQ_PNP_PROP("SID", "Seiko Instruments Information Devices Inc"),
	__AQ_PNP_PROP("SIE", "Siemens"),
	__AQ_PNP_PROP("SIG", "Sigma Designs Inc"),
	__AQ_PNP_PROP("SII", "Silicon Image, Inc."),
	__AQ_PNP_PROP("SIL", "Silicon Laboratories, Inc"),
	__AQ_PNP_PROP("SIM", "S3 Inc"),
	__AQ_PNP_PROP("SIN", "Singular Technology Co., Ltd."),
	__AQ_PNP_PROP("SIR", "Sirius Technologies Pty Ltd"),
	__AQ_PNP_PROP("SIS", "Silicon Integrated Systems Corporation"),
	__AQ_PNP_PROP("SIT", "Sitintel"),
	__AQ_PNP_PROP("SIU", "Seiko Instruments USA Inc"),
	__AQ_PNP_PROP("SIX", "Zuniq Data Corporation"),
	__AQ_PNP_PROP("SJE", "Sejin Electron Inc"),
	__AQ_PNP_PROP("SKD", "Schneider & Koch"),
	__AQ_PNP_PROP("SKG", "Shenzhen KTC Technology Group"),
	__AQ_PNP_PROP("SKI", "LLC SKTB “SKIT”"),
	__AQ_PNP_PROP("SKM", "Guangzhou Teclast Information Technology Limited"),
	__AQ_PNP_PROP("SKT", "Samsung Electro-Mechanics Company Ltd"),
	__AQ_PNP_PROP("SKW", "Skyworth"),
	__AQ_PNP_PROP("SKY", "SKYDATA S.P.A."),
	__AQ_PNP_PROP("SLA", "Systeme Lauer GmbH&Co KG"),
	__AQ_PNP_PROP("SLB", "Shlumberger Ltd"),
	__AQ_PNP_PROP("SLC", "Syslogic Datentechnik AG"),
	__AQ_PNP_PROP("SLF", "StarLeaf"),
	__AQ_PNP_PROP("SLH", "Silicon Library Inc."),
	__AQ_PNP_PROP("SLI", "Symbios Logic Inc"),
	__AQ_PNP_PROP("SLK", "Silitek Corporation"),
	__AQ_PNP_PROP("SLM", "Solomon Technology Corporation"),
	__AQ_PNP_PROP("SLR", "Schlumberger Technology Corporate"),
	__AQ_PNP_PROP("SLS", "Schnick-Schnack-Systems GmbH"),
	__AQ_PNP_PROP("SLT", "Salt Internatioinal Corp."),
	__AQ_PNP_PROP("SLX", "Specialix"),
	__AQ_PNP_PROP("SMA", "SMART Modular Technologies"),
	__AQ_PNP_PROP("SMB", "Schlumberger"),
	__AQ_PNP_PROP("SMC", "Standard Microsystems Corporation"),
	__AQ_PNP_PROP("SME", "Sysmate Company"),
	__AQ_PNP_PROP("SMI", "SpaceLabs Medical Inc"),
	__AQ_PNP_PROP("SMK", "SMK CORPORATION"),
	__AQ_PNP_PROP("SML", "Sumitomo Metal Industries, Ltd."),
	__AQ_PNP_PROP("SMM", "Shark Multimedia Inc"),
	__AQ_PNP_PROP("SMN", "Somnium Space Ltd."),
	__AQ_PNP_PROP("SMO", "STMicroelectronics"),
	__AQ_PNP_PROP("SMP", "Simple Computing"),
	__AQ_PNP_PROP("SMR", "B.& V. s.r.l."),
	__AQ_PNP_PROP("SMS", "Silicom Multimedia Systems Inc"),
	__AQ_PNP_PROP("SMT", "Silcom Manufacturing Tech Inc"),
	__AQ_PNP_PROP("SNC", "Sentronic International Corp."),
	__AQ_PNP_PROP("SNI", "Siemens Microdesign GmbH"),
	__AQ_PNP_PROP("SNK", "S&K Electronics"),
	__AQ_PNP_PROP("SNN", "SUNNY ELEKTRONIK"),
	__AQ_PNP_PROP("SNO", "SINOSUN TECHNOLOGY CO., LTD"),
	__AQ_PNP_PROP("SNP", "Siemens Nixdorf Info Systems"),
	__AQ_PNP_PROP("SNS", "Cirtech (UK) Ltd"),
	__AQ_PNP_PROP("SNT", "SuperNet Inc"),
	__AQ_PNP_PROP("SNV", "SONOVE GmbH"),
	__AQ_PNP_PROP("SNW", "Snell & Wilcox"),
	__AQ_PNP_PROP("SNX", "Sonix Comm. Ltd"),
	__AQ_PNP_PROP("SNY", "Sony"),
	__AQ_PNP_PROP("SOC", "Santec Corporation"),
	__AQ_PNP_PROP("SOI", "Silicon Optix Corporation"),
	__AQ_PNP_PROP("SOL", "Solitron Technologies Inc"),
	__AQ_PNP_PROP("SON", "Sony"),
	__AQ_PNP_PROP("SOR", "Sorcus Computer GmbH"),
	__AQ_PNP_PROP("SOT", "Sotec Company Ltd"),
	__AQ_PNP_PROP("SOY", "SOYO Group, Inc"),
	__AQ_PNP_PROP("SPC", "SpinCore Technologies, Inc"),
	__AQ_PNP_PROP("SPE", "SPEA Software AG"),
	__AQ_PNP_PROP("SPH", "G&W Instruments GmbH"),
	__AQ_PNP_PROP("SPI", "SPACE-I Co., Ltd."),
	__AQ_PNP_PROP("SPK", "SpeakerCraft"),
	__AQ_PNP_PROP("SPL", "Smart Silicon Systems Pty Ltd"),
	__AQ_PNP_PROP("SPN", "Sapience Corporation"),
	__AQ_PNP_PROP("SPO", "SAMPO CORPORATION"),
	__AQ_PNP_PROP("SPR", "pmns GmbH"),
	__AQ_PNP_PROP("SPS", "Synopsys Inc"),
	__AQ_PNP_PROP("SPT", "Sceptre Tech Inc"),
	__AQ_PNP_PROP("SPU", "SIM2 Multimedia S.P.A."),
	__AQ_PNP_PROP("SPX", "Simplex Time Recorder Co."),
	__AQ_PNP_PROP("SQT", "Sequent Computer Systems Inc"),
	__AQ_PNP_PROP("SRC", "Integrated Tech Express Inc"),
	__AQ_PNP_PROP("SRD", "Setred"),
	__AQ_PNP_PROP("SRF", "Surf Communication Solutions Ltd"),
	__AQ_PNP_PROP("SRG", "Intuitive Surgical, Inc."),
	__AQ_PNP_PROP("SRS", "SR-Systems e.K."),
	__AQ_PNP_PROP("SRT", "SeeReal Technologies GmbH"),
	__AQ_PNP_PROP("SSC", "Sierra Semiconductor Inc"),
	__AQ_PNP_PROP("SSD", "FlightSafety International"),
	__AQ_PNP_PROP("SSE", "Samsung Electronic Co."),
	__AQ_PNP_PROP("SSG", "Steelseries ApS"),
	__AQ_PNP_PROP("SSI", "S-S Technology Inc"),
	__AQ_PNP_PROP("SSJ", "Sankyo Seiki Mfg.co., Ltd"),
	__AQ_PNP_PROP("SSL", "Shenzhen South-Top Computer Co., Ltd."),
	__AQ_PNP_PROP("SSP", "Spectrum Signal Proecessing Inc"),
	__AQ_PNP_PROP("SSS", "S3 Inc"),
	__AQ_PNP_PROP("SST", "SystemSoft Corporation"),
	__AQ_PNP_PROP("STA", "ST Electronics Systems Assembly Pte Ltd"),
	__AQ_PNP_PROP("STB", "STB Systems Inc"),
	__AQ_PNP_PROP("STC", "STAC Electronics"),
	__AQ_PNP_PROP("STD", "STD Computer Inc"),
	__AQ_PNP_PROP("STE", "SII Ido-Tsushin Inc"),
	__AQ_PNP_PROP("STF", "Starflight Electronics"),
	__AQ_PNP_PROP("STG", "StereoGraphics Corp."),
	__AQ_PNP_PROP("STH", "Semtech Corporation"),
	__AQ_PNP_PROP("STI", "Smart Tech Inc"),
	__AQ_PNP_PROP("STK", "SANTAK CORP."),
	__AQ_PNP_PROP("STL", "SigmaTel Inc"),
	__AQ_PNP_PROP("STM", "SGS Thomson Microelectronics"),
	__AQ_PNP_PROP("STN", "Samsung Electronics America"),
	__AQ_PNP_PROP("STO", "Stollmann E+V GmbH"),
	__AQ_PNP_PROP("STP", "StreamPlay Ltd"),
	__AQ_PNP_PROP("STQ", "Synthetel Corporation"),
	__AQ_PNP_PROP("STR", "Starlight Networks Inc"),
	__AQ_PNP_PROP("STS", "SITECSYSTEM CO., LTD."),
	__AQ_PNP_PROP("STT", "Star Paging Telecom Tech (Shenzhen) Co. Ltd."),
	__AQ_PNP_PROP("STU", "Sentelic Corporation"),
	__AQ_PNP_PROP("STV", "Beijing Guochengwantong Information Technology Co., Ltd."),
	__AQ_PNP_PROP("STW", "Starwin Inc."),
	__AQ_PNP_PROP("STX", "ST-Ericsson"),
	__AQ_PNP_PROP("STY", "SDS Technologies"),
	__AQ_PNP_PROP("SUB", "Subspace Comm. Inc"),
	__AQ_PNP_PROP("SUM", "Summagraphics Corporation"),
	__AQ_PNP_PROP("SUN", "Sun Electronics Corporation"),
	__AQ_PNP_PROP("SUP", "Supra Corporation"),
	__AQ_PNP_PROP("SUR", "Surenam Computer Corporation"),
	__AQ_PNP_PROP("SVA", "SGEG"),
	__AQ_PNP_PROP("SVC", "Intellix Corp."),
	__AQ_PNP_PROP("SVD", "SVD Computer"),
	__AQ_PNP_PROP("SVI", "Sun Microsystems"),
	__AQ_PNP_PROP("SVR", "Sensics, Inc."),
	__AQ_PNP_PROP("SVS", "SVSI"),
	__AQ_PNP_PROP("SVT", "SEVIT Co., Ltd."),
	__AQ_PNP_PROP("SWC", "Software Café"),
	__AQ_PNP_PROP("SWI", "Sierra Wireless Inc."),
	__AQ_PNP_PROP("SWL", "Sharedware Ltd"),
	__AQ_PNP_PROP("SWO", "Guangzhou Shirui Electronics Co., Ltd."),
	__AQ_PNP_PROP("SWS", "Static"),
	__AQ_PNP_PROP("SWT", "Software Technologies Group,Inc."),
	__AQ_PNP_PROP("SXB", "Syntax-Brillian"),
	__AQ_PNP_PROP("SXD", "Silex technology, Inc."),
	__AQ_PNP_PROP("SXG", "SELEX GALILEO"),
	__AQ_PNP_PROP("SXI", "Silex Inside"),
	__AQ_PNP_PROP("SXL", "SolutionInside"),
	__AQ_PNP_PROP("SXT", "SHARP TAKAYA ELECTRONIC INDUSTRY CO.,LTD."),
	__AQ_PNP_PROP("SYC", "Sysmic"),
	__AQ_PNP_PROP("SYE", "SY Electronics Ltd"),
	__AQ_PNP_PROP("SYK", "Stryker Communications"),
	__AQ_PNP_PROP("SYL", "Sylvania Computer Products"),
	__AQ_PNP_PROP("SYM", "Symicron Computer Communications Ltd."),
	__AQ_PNP_PROP("SYN", "Synaptics Inc"),
	__AQ_PNP_PROP("SYP", "SYPRO Co Ltd"),
	__AQ_PNP_PROP("SYS", "Sysgration Ltd"),
	__AQ_PNP_PROP("SYT", "Seyeon Tech Company Ltd"),
	__AQ_PNP_PROP("SYV", "SYVAX Inc"),
	__AQ_PNP_PROP("SYX", "Prime Systems, Inc."),
	__AQ_PNP_PROP("SZM", "Shenzhen MTC Co., Ltd"),
	__AQ_PNP_PROP("TAA", "Tandberg"),
	__AQ_PNP_PROP("TAB", "Todos Data System AB"),
	__AQ_PNP_PROP("TAG", "Teles AG"),
	__AQ_PNP_PROP("TAI", "Toshiba America Info Systems Inc"),
	__AQ_PNP_PROP("TAM", "Tamura Seisakusyo Ltd"),
	__AQ_PNP_PROP("TAS", "Taskit Rechnertechnik GmbH"),
	__AQ_PNP_PROP("TAT", "Teleliaison Inc"),
	__AQ_PNP_PROP("TAV", "Thales Avionics"),
	__AQ_PNP_PROP("TAX", "Taxan (Europe) Ltd"),
	__AQ_PNP_PROP("TBB", "Triple S Engineering Inc"),
	__AQ_PNP_PROP("TBC", "Turbo Communication, Inc"),
	__AQ_PNP_PROP("TBS", "Turtle Beach System"),
	__AQ_PNP_PROP("TCC", "Tandon Corporation"),
	__AQ_PNP_PROP("TCD", "Taicom Data Systems Co., Ltd."),
	__AQ_PNP_PROP("TCE", "Century Corporation"),
	__AQ_PNP_PROP("TCF", "Televic Conference"),
	__AQ_PNP_PROP("TCH", "Interaction Systems, Inc"),
	__AQ_PNP_PROP("TCI", "Tulip Computers Int'l B.V."),
	__AQ_PNP_PROP("TCJ", "TEAC America Inc"),
	__AQ_PNP_PROP("TCL", "Technical Concepts Ltd"),
	__AQ_PNP_PROP("TCM", "3Com Corporation"),
	__AQ_PNP_PROP("TCN", "Tecnetics (PTY) Ltd"),
	__AQ_PNP_PROP("TCO", "Thomas-Conrad Corporation"),
	__AQ_PNP_PROP("TCR", "Thomson Consumer Electronics"),
	__AQ_PNP_PROP("TCS", "Tatung Company of America Inc"),
	__AQ_PNP_PROP("TCT", "Telecom Technology Centre Co. Ltd."),
	__AQ_PNP_PROP("TCX", "FREEMARS Heavy Industries"),
	__AQ_PNP_PROP("TDC", "Teradici"),
	__AQ_PNP_PROP("TDD", "Tandberg Data Display AS"),
	__AQ_PNP_PROP("TDG", "Six15 Technologies"),
	__AQ_PNP_PROP("TDM", "Tandem Computer Europe Inc"),
	__AQ_PNP_PROP("TDP", "3D Perception"),
	__AQ_PNP_PROP("TDS", "Tri-Data Systems Inc"),
	__AQ_PNP_PROP("TDT", "TDT"),
	__AQ_PNP_PROP("TDV", "TDVision Systems, Inc."),
	__AQ_PNP_PROP("TDY", "Tandy Electronics"),
	__AQ_PNP_PROP("TEA", "TEAC System Corporation"),
	__AQ_PNP_PROP("TEC", "Tecmar Inc"),
	__AQ_PNP_PROP("TEK", "Tektronix Inc"),
	__AQ_PNP_PROP("TEL", "Promotion and Display Technology Ltd."),
	__AQ_PNP_PROP("TEN", "Tencent"),
	__AQ_PNP_PROP("TER", "TerraTec Electronic GmbH"),
	__AQ_PNP_PROP("TET", "TETRADYNE CO., LTD."),
	__AQ_PNP_PROP("TEV", "Televés, S.A."),
	__AQ_PNP_PROP("TEZ", "Tech Source Inc."),
	__AQ_PNP_PROP("TGC", "Toshiba Global Commerce Solutions, Inc."),
	__AQ_PNP_PROP("TGI", "TriGem Computer Inc"),
	__AQ_PNP_PROP("TGM", "TriGem Computer,Inc."),
	__AQ_PNP_PROP("TGS", "Torus Systems Ltd"),
	__AQ_PNP_PROP("TGV", "Grass Valley Germany GmbH"),
	__AQ_PNP_PROP("TGW", "TECHNOGYM S.p.A."),
	__AQ_PNP_PROP("THN", "Thundercom Holdings Sdn. Bhd."),
	__AQ_PNP_PROP("TIC", "Trigem KinfoComm"),
	__AQ_PNP_PROP("TIL", "Technical Illusions Inc."),
	__AQ_PNP_PROP("TIP", "TIPTEL AG"),
	__AQ_PNP_PROP("TIV", "OOO Technoinvest"),
	__AQ_PNP_PROP("TIX", "Tixi.Com GmbH"),
	__AQ_PNP_PROP("TKC", "Taiko Electric Works.LTD"),
	__AQ_PNP_PROP("TKG", "Tek Gear"),
	__AQ_PNP_PROP("TKN", "Teknor Microsystem Inc"),
	__AQ_PNP_PROP("TKO", "TouchKo, Inc."),
	__AQ_PNP_PROP("TKS", "TimeKeeping Systems, Inc."),
	__AQ_PNP_PROP("TLA", "Ferrari Electronic GmbH"),
	__AQ_PNP_PROP("TLD", "Telindus"),
	__AQ_PNP_PROP("TLE", "Zhejiang Tianle Digital Electric Co., Ltd."),
	__AQ_PNP_PROP("TLF", "Teleforce.,co,ltd"),
	__AQ_PNP_PROP("TLI", "TOSHIBA TELI CORPORATION"),
	__AQ_PNP_PROP("TLK", "Telelink AG"),
	__AQ_PNP_PROP("TLL", "Thinklogical"),
	__AQ_PNP_PROP("TLN", "Techlogix Networx"),
	__AQ_PNP_PROP("TLS", "Teleste Educational OY"),
	__AQ_PNP_PROP("TLT", "Dai Telecom S.p.A."),
	__AQ_PNP_PROP("TLV", "S3 Inc"),
	__AQ_PNP_PROP("TLX", "Telxon Corporation"),
	__AQ_PNP_PROP("TLY", "Truly Semiconductors Ltd."),
	__AQ_PNP_PROP("TMA", "Tianma Microelectronics Ltd."),
	__AQ_PNP_PROP("TMC", "Techmedia Computer Systems Corporation"),
	__AQ_PNP_PROP("TME", "AT&T Microelectronics"),
	__AQ_PNP_PROP("TMI", "Texas Microsystem"),
	__AQ_PNP_PROP("TMM", "Time Management, Inc."),
	__AQ_PNP_PROP("TMO", "Terumo Corporation"),
	__AQ_PNP_PROP("TMR", "Taicom International Inc"),
	__AQ_PNP_PROP("TMS", "Trident Microsystems Ltd"),
	__AQ_PNP_PROP("TMT", "T-Metrics Inc."),
	__AQ_PNP_PROP("TMV", "TeamViewer Germany GmbH"),
	__AQ_PNP_PROP("TMX", "Thermotrex Corporation"),
	__AQ_PNP_PROP("TNC", "TNC Industrial Company Ltd"),
	__AQ_PNP_PROP("TNJ", "Invalid Vendor Codename - TNJ"),
	__AQ_PNP_PROP("TNM", "TECNIMAGEN SA"),
	__AQ_PNP_PROP("TNY", "Tennyson Tech Pty Ltd"),
	__AQ_PNP_PROP("TOE", "TOEI Electronics Co., Ltd."),
	__AQ_PNP_PROP("TOG", "The OPEN Group"),
	__AQ_PNP_PROP("TOL", "TCL Corporation"),
	__AQ_PNP_PROP("TOM", "Ceton Corporation"),
	__AQ_PNP_PROP("TON", "TONNA"),
	__AQ_PNP_PROP("TOP", "Orion Communications Co., Ltd."),
	__AQ_PNP_PROP("TOS", "Dynabook Inc."),
	__AQ_PNP_PROP("TOU", "Touchstone Technology"),
	__AQ_PNP_PROP("TPC", "Touch Panel Systems Corporation"),
	__AQ_PNP_PROP("TPD", "Times (Shanghai) Computer Co., Ltd."),
	__AQ_PNP_PROP("TPE", "Technology Power Enterprises Inc"),
	__AQ_PNP_PROP("TPJ", "Junnila"),
	__AQ_PNP_PROP("TPK", "TOPRE CORPORATION"),
	__AQ_PNP_PROP("TPR", "Topro Technology Inc"),
	__AQ_PNP_PROP("TPS", "Teleprocessing Systeme GmbH"),
	__AQ_PNP_PROP("TPT", "Thruput Ltd"),
	__AQ_PNP_PROP("TPV", "Top Victory Electronics ( Fujian ) Company Ltd"),
	__AQ_PNP_PROP("TPZ", "Ypoaz Systems Inc"),
	__AQ_PNP_PROP("TRA", "TriTech Microelectronics International"),
	__AQ_PNP_PROP("TRB", "Triumph Board a.s."),
	__AQ_PNP_PROP("TRC", "Trioc AB"),
	__AQ_PNP_PROP("TRD", "Trident Microsystem Inc"),
	__AQ_PNP_PROP("TRE", "Tremetrics"),
	__AQ_PNP_PROP("TRI", "Tricord Systems"),
	__AQ_PNP_PROP("TRL", "Royal Information"),
	__AQ_PNP_PROP("TRM", "Tekram Technology Company Ltd"),
	__AQ_PNP_PROP("TRN", "Datacommunicatie Tron B.V."),
	__AQ_PNP_PROP("TRP", "TRAPEZE GROUP"),
	__AQ_PNP_PROP("TRS", "Torus Systems Ltd"),
	__AQ_PNP_PROP("TRT", "Tritec Electronic AG"),
	__AQ_PNP_PROP("TRU", "Aashima Technology B.V."),
	__AQ_PNP_PROP("TRV", "Trivisio Prototyping GmbH"),
	__AQ_PNP_PROP("TRX", "Trex Enterprises"),
	__AQ_PNP_PROP("TSB", "Toshiba America Info Systems Inc"),
	__AQ_PNP_PROP("TSC", "Sanyo Electric Company Ltd"),
	__AQ_PNP_PROP("TSD", "TechniSat Digital GmbH"),
	__AQ_PNP_PROP("TSE", "Tottori Sanyo Electric"),
	__AQ_PNP_PROP("TSF", "Racal-Airtech Software Forge Ltd"),
	__AQ_PNP_PROP("TSG", "The Software Group Ltd"),
	__AQ_PNP_PROP("TSH", "ELAN MICROELECTRONICS CORPORATION"),
	__AQ_PNP_PROP("TSI", "TeleVideo Systems"),
	__AQ_PNP_PROP("TSL", "Tottori SANYO Electric Co., Ltd."),
	__AQ_PNP_PROP("TSP", "U.S. Navy"),
	__AQ_PNP_PROP("TST", "Transtream Inc"),
	__AQ_PNP_PROP("TSV", "TRANSVIDEO"),
	__AQ_PNP_PROP("TSW", "VRSHOW Technology Limited"),
	__AQ_PNP_PROP("TSY", "TouchSystems"),
	__AQ_PNP_PROP("TTA", "Topson Technology Co., Ltd."),
	__AQ_PNP_PROP("TTB", "National Semiconductor Japan Ltd"),
	__AQ_PNP_PROP("TTC", "Telecommunications Techniques Corporation"),
	__AQ_PNP_PROP("TTE", "TTE, Inc."),
	__AQ_PNP_PROP("TTI", "Trenton Terminals Inc"),
	__AQ_PNP_PROP("TTK", "Totoku Electric Company Ltd"),
	__AQ_PNP_PROP("TTL", "2-Tel B.V"),
	__AQ_PNP_PROP("TTP", "Toshiba Corporation"),
	__AQ_PNP_PROP("TTR", "Hubei Century Joint Innovation Technology Co.Ltd"),
	__AQ_PNP_PROP("TTS", "TechnoTrend Systemtechnik GmbH"),
	__AQ_PNP_PROP("TTX", "Taitex Corporation"),
	__AQ_PNP_PROP("TTY", "TRIDELITY Display Solutions GmbH"),
	__AQ_PNP_PROP("TUA", "T+A elektroakustik GmbH"),
	__AQ_PNP_PROP("TUT", "Tut Systems"),
	__AQ_PNP_PROP("TVD", "Tecnovision"),
	__AQ_PNP_PROP("TVI", "Truevision"),
	__AQ_PNP_PROP("TVL", "Total Vision LTD"),
	__AQ_PNP_PROP("TVM", "Taiwan Video & Monitor Corporation"),
	__AQ_PNP_PROP("TVO", "TV One Ltd"),
	__AQ_PNP_PROP("TVR", "TV Interactive Corporation"),
	__AQ_PNP_PROP("TVS", "TVS Electronics Limited"),
	__AQ_PNP_PROP("TVV", "TV1 GmbH"),
	__AQ_PNP_PROP("TWA", "Tidewater Association"),
	__AQ_PNP_PROP("TWE", "Kontron Electronik"),
	__AQ_PNP_PROP("TWH", "Twinhead International Corporation"),
	__AQ_PNP_PROP("TWI", "Easytel oy"),
	__AQ_PNP_PROP("TWK", "TOWITOKO electronics GmbH"),
	__AQ_PNP_PROP("TWX", "TEKWorx Limited"),
	__AQ_PNP_PROP("TXL", "Trixel Ltd"),
	__AQ_PNP_PROP("TXN", "Texas Insturments"),
	__AQ_PNP_PROP("TXT", "Textron Defense System"),
	__AQ_PNP_PROP("TYN", "Tyan Computer Corporation"),
	__AQ_PNP_PROP("UAS", "Ultima Associates Pte Ltd"),
	__AQ_PNP_PROP("UBI", "Ungermann-Bass Inc"),
	__AQ_PNP_PROP("UBL", "Ubinetics Ltd."),
	__AQ_PNP_PROP("UBU", "Canonical Ltd."),
	__AQ_PNP_PROP("UDN", "Uniden Corporation"),
	__AQ_PNP_PROP("UEC", "Ultima Electronics Corporation"),
	__AQ_PNP_PROP("UEG", "Elitegroup Computer Systems Company Ltd"),
	__AQ_PNP_PROP("UEI", "Universal Electronics Inc"),
	__AQ_PNP_PROP("UET", "Universal Empowering Technologies"),
	__AQ_PNP_PROP("UFG", "UNIGRAF-USA"),
	__AQ_PNP_PROP("UFO", "UFO Systems Inc"),
	__AQ_PNP_PROP("UGR", "Ugreen Group Ltd."),
	__AQ_PNP_PROP("UHB", "XOCECO"),
	__AQ_PNP_PROP("UIC", "Uniform Industrial Corporation"),
	__AQ_PNP_PROP("UJR", "Ueda Japan Radio Co., Ltd."),
	__AQ_PNP_PROP("ULT", "Ultra Network Tech"),
	__AQ_PNP_PROP("UMC", "United Microelectr Corporation"),
	__AQ_PNP_PROP("UMG", "Umezawa Giken Co.,Ltd"),
	__AQ_PNP_PROP("UMM", "Universal Multimedia"),
	__AQ_PNP_PROP("UMT", "UltiMachine"),
	__AQ_PNP_PROP("UNA", "Unisys DSD"),
	__AQ_PNP_PROP("UNB", "Unisys Corporation"),
	__AQ_PNP_PROP("UNC", "Unisys Corporation"),
	__AQ_PNP_PROP("UND", "Unisys Corporation"),
	__AQ_PNP_PROP("UNE", "Unisys Corporation"),
	__AQ_PNP_PROP("UNF", "Unisys Corporation"),
	__AQ_PNP_PROP("UNI", "Uniform Industry Corp."),
	__AQ_PNP_PROP("UNM", "Unisys Corporation"),
	__AQ_PNP_PROP("UNO", "Unisys Corporation"),
	__AQ_PNP_PROP("UNP", "Unitop"),
	__AQ_PNP_PROP("UNS", "Unisys Corporation"),
	__AQ_PNP_PROP("UNT", "Unisys Corporation"),
	__AQ_PNP_PROP("UNY", "Unicate"),
	__AQ_PNP_PROP("UPP", "UPPI"),
	__AQ_PNP_PROP("UPS", "Systems Enhancement"),
	__AQ_PNP_PROP("URD", "Video Computer S.p.A."),
	__AQ_PNP_PROP("USA", "Utimaco Safeware AG"),
	__AQ_PNP_PROP("USD", "U.S. Digital Corporation"),
	__AQ_PNP_PROP("USE", "U. S. Electronics Inc."),
	__AQ_PNP_PROP("USI", "Universal Scientific Industrial Co., Ltd."),
	__AQ_PNP_PROP("USR", "U.S. Robotics Inc"),
	__AQ_PNP_PROP("UTC", "Unicompute Technology Co., Ltd."),
	__AQ_PNP_PROP("UTD", "Up to Date Tech"),
	__AQ_PNP_PROP("UWC", "Uniwill Computer Corp."),
	__AQ_PNP_PROP("VAD", "Vaddio, LLC"),
	__AQ_PNP_PROP("VAI", "VAIO Corporation"),
	__AQ_PNP_PROP("VAL", "Valence Computing Corporation"),
	__AQ_PNP_PROP("VAR", "Varian Australia Pty Ltd"),
	__AQ_PNP_PROP("VAT", "VADATECH INC"),
	__AQ_PNP_PROP("VAV", "aviica"),
	__AQ_PNP_PROP("VBR", "VBrick Systems Inc."),
	__AQ_PNP_PROP("VBT", "Valley Board Ltda"),
	__AQ_PNP_PROP("VCC", "Virtual Computer Corporation"),
	__AQ_PNP_PROP("VCE", "VARCem"),
	__AQ_PNP_PROP("VCI", "VistaCom Inc"),
	__AQ_PNP_PROP("VCJ", "Victor Company of Japan, Limited"),
	__AQ_PNP_PROP("VCM", "Vector Magnetics, LLC"),
	__AQ_PNP_PROP("VCX", "VCONEX"),
	__AQ_PNP_PROP("VDA", "Victor Data Systems"),
	__AQ_PNP_PROP("VDC", "VDC Display Systems"),
	__AQ_PNP_PROP("VDM", "Vadem"),
	__AQ_PNP_PROP("VDO", "Video & Display Oriented Corporation"),
	__AQ_PNP_PROP("VDS", "Vidisys GmbH & Company"),
	__AQ_PNP_PROP("VDT", "Viditec, Inc."),
	__AQ_PNP_PROP("VEC", "Vector Informatik GmbH"),
	__AQ_PNP_PROP("VEK", "Vektrex"),
	__AQ_PNP_PROP("VES", "Vestel Elektronik Sanayi ve Ticaret A. S."),
	__AQ_PNP_PROP("VFI", "VeriFone Inc"),
	__AQ_PNP_PROP("VHI", "Macrocad Development Inc."),
	__AQ_PNP_PROP("VIA", "VIA Tech Inc"),
	__AQ_PNP_PROP("VIB", "Tatung UK Ltd"),
	__AQ_PNP_PROP("VIC", "Victron B.V."),
	__AQ_PNP_PROP("VID", "Ingram Macrotron Germany"),
	__AQ_PNP_PROP("VIK", "Viking Connectors"),
	__AQ_PNP_PROP("VIM", "Via Mons Ltd."),
	__AQ_PNP_PROP("VIN", "Vine Micros Ltd"),
	__AQ_PNP_PROP("VIO", "Zake IP Holdings LLC (3B tech)"),
	__AQ_PNP_PROP("VIR", "Visual Interface, Inc"),
	__AQ_PNP_PROP("VIS", "Visioneer"),
	__AQ_PNP_PROP("VIT", "Visitech AS"),
	__AQ_PNP_PROP("VIZ", "VIZIO, Inc"),
	__AQ_PNP_PROP("VLB", "ValleyBoard Ltda."),
	__AQ_PNP_PROP("VLC", "VersaLogic Corporation"),
	__AQ_PNP_PROP("VLK", "Vislink International Ltd"),
	__AQ_PNP_PROP("VLM", "LENOVO BEIJING CO. LTD."),
	__AQ_PNP_PROP("VLT", "VideoLan Technologies"),
	__AQ_PNP_PROP("VLV", "Valve Corporation"),
	__AQ_PNP_PROP("VMI", "Vermont Microsystems"),
	__AQ_PNP_PROP("VML", "Vine Micros Limited"),
	__AQ_PNP_PROP("VMW", "VMware Inc.,"),
	__AQ_PNP_PROP("VNC", "Vinca Corporation"),
	__AQ_PNP_PROP("VNX", "Venetex Corporation"),
	__AQ_PNP_PROP("VOB", "MaxData Computer AG"),
	__AQ_PNP_PROP("VPI", "Video Products Inc"),
	__AQ_PNP_PROP("VPR", "Best Buy"),
	__AQ_PNP_PROP("VPX", "VPixx Technologies Inc."),
	__AQ_PNP_PROP("VQ@", "Vision Quest"),
	__AQ_PNP_PROP("VRC", "Virtual Resources Corporation"),
	__AQ_PNP_PROP("VRG", "VRgineers, Inc."),
	__AQ_PNP_PROP("VRM", "VRmagic Holding AG"),
	__AQ_PNP_PROP("VRS", "VRstudios, Inc."),
	__AQ_PNP_PROP("VRT", "Varjo Technologies"),
	__AQ_PNP_PROP("VSC", "ViewSonic Corporation"),
	__AQ_PNP_PROP("VSD", "3M"),
	__AQ_PNP_PROP("VSI", "VideoServer"),
	__AQ_PNP_PROP("VSN", "Ingram Macrotron"),
	__AQ_PNP_PROP("VSP", "Vision Systems GmbH"),
	__AQ_PNP_PROP("VSR", "V-Star Electronics Inc."),
	__AQ_PNP_PROP("VTB", "Videotechnik Breithaupt"),
	__AQ_PNP_PROP("VTC", "VTel Corporation"),
	__AQ_PNP_PROP("VTG", "Voice Technologies Group Inc"),
	__AQ_PNP_PROP("VTI", "VLSI Tech Inc"),
	__AQ_PNP_PROP("VTK", "Viewteck Co., Ltd."),
	__AQ_PNP_PROP("VTL", "Vivid Technology Pte Ltd"),
	__AQ_PNP_PROP("VTM", "Miltope Corporation"),
	__AQ_PNP_PROP("VTN", "VIDEOTRON CORP."),
	__AQ_PNP_PROP("VTS", "VTech Computers Ltd"),
	__AQ_PNP_PROP("VTV", "VATIV Technologies"),
	__AQ_PNP_PROP("VTX", "Vestax Corporation"),
	__AQ_PNP_PROP("VUT", "Vutrix (UK) Ltd"),
	__AQ_PNP_PROP("VVI", "VITEC"),
	__AQ_PNP_PROP("VWB", "Vweb Corp."),
	__AQ_PNP_PROP("WAC", "Wacom Tech"),
	__AQ_PNP_PROP("WAL", "Wave Access"),
	__AQ_PNP_PROP("WAN", "Invalid Vendor Codename - WAN"),
	__AQ_PNP_PROP("WAV", "Wavephore"),
	__AQ_PNP_PROP("WBN", "MicroSoftWare"),
	__AQ_PNP_PROP("WBS", "WB Systemtechnik GmbH"),
	__AQ_PNP_PROP("WCI", "Wisecom Inc"),
	__AQ_PNP_PROP("WCS", "Woodwind Communications Systems Inc"),
	__AQ_PNP_PROP("WDC", "Western Digital"),
	__AQ_PNP_PROP("WDE", "Westinghouse Digital Electronics"),
	__AQ_PNP_PROP("WEB", "WebGear Inc"),
	__AQ_PNP_PROP("WEC", "Winbond Electronics Corporation"),
	__AQ_PNP_PROP("WEL", "W-DEV"),
	__AQ_PNP_PROP("WEY", "WEY Design AG"),
	__AQ_PNP_PROP("WHI", "Whistle Communications"),
	__AQ_PNP_PROP("WII", "Innoware Inc"),
	__AQ_PNP_PROP("WIL", "WIPRO Information Technology Ltd"),
	__AQ_PNP_PROP("WIN", "Wintop Technology Inc"),
	__AQ_PNP_PROP("WIP", "Wipro Infotech"),
	__AQ_PNP_PROP("WKH", "Uni-Take Int'l Inc."),
	__AQ_PNP_PROP("WLD", "Wildfire Communications Inc"),
	__AQ_PNP_PROP("WLF", "WOLF Advanced Technology"),
	__AQ_PNP_PROP("WMI", "Weidmuller Interface GmbH & Co. KG"),
	__AQ_PNP_PROP("WML", "Wolfson Microelectronics Ltd"),
	__AQ_PNP_PROP("WMO", "Westermo Teleindustri AB"),
	__AQ_PNP_PROP("WMT", "Winmate Communication Inc"),
	__AQ_PNP_PROP("WNI", "WillNet Inc."),
	__AQ_PNP_PROP("WNV", "Winnov L.P."),
	__AQ_PNP_PROP("WNX", "Diebold Nixdorf Systems GmbH"),
	__AQ_PNP_PROP("WPA", "Matsushita Communication Industrial Co., Ltd."),
	__AQ_PNP_PROP("WPI", "Wearnes Peripherals International (Pte) Ltd"),
	__AQ_PNP_PROP("WRC", "WiNRADiO Communications"),
	__AQ_PNP_PROP("WSC", "CIS Technology Inc"),
	__AQ_PNP_PROP("WSP", "Wireless And Smart Products Inc."),
	__AQ_PNP_PROP("WST", "Wistron Corporation"),
	__AQ_PNP_PROP("WTC", "ACC Microelectronics"),
	__AQ_PNP_PROP("WTI", "WorkStation Tech"),
	__AQ_PNP_PROP("WTK", "Wearnes Thakral Pte"),
	__AQ_PNP_PROP("WTS", "Restek Electric Company Ltd"),
	__AQ_PNP_PROP("WVM", "Wave Systems Corporation"),
	__AQ_PNP_PROP("WVV", "WolfVision GmbH"),
	__AQ_PNP_PROP("WWP", "Wipotec Wiege- und Positioniersysteme GmbH"),
	__AQ_PNP_PROP("WWV", "World Wide Video, Inc."),
	__AQ_PNP_PROP("WXT", "Woxter Technology Co. Ltd"),
	__AQ_PNP_PROP("WYR", "WyreStorm Technologies LLC"),
	__AQ_PNP_PROP("WYS", "Wyse Technology"),
	__AQ_PNP_PROP("WYT", "Wooyoung Image & Information Co.,Ltd."),
	__AQ_PNP_PROP("XAC", "XAC Automation Corp"),
	__AQ_PNP_PROP("XAD", "Alpha Data"),
	__AQ_PNP_PROP("XDM", "XDM Ltd."),
	__AQ_PNP_PROP("XER", "Invalid Vendor Codename - XER"),
	__AQ_PNP_PROP("XES", "Extreme Engineering Solutions, Inc."),
	__AQ_PNP_PROP("XFG", "Jan Strapko - FOTO"),
	__AQ_PNP_PROP("XFO", "EXFO Electro Optical Engineering"),
	__AQ_PNP_PROP("XIN", "Xinex Networks Inc"),
	__AQ_PNP_PROP("XIO", "Xiotech Corporation"),
	__AQ_PNP_PROP("XIR", "Xirocm Inc"),
	__AQ_PNP_PROP("XIT", "Xitel Pty ltd"),
	__AQ_PNP_PROP("XLX", "Xilinx, Inc."),
	__AQ_PNP_PROP("XMI", "Xiaomi Corporation"),
	__AQ_PNP_PROP("XMM", "C3PO S.L."),
	__AQ_PNP_PROP("XNT", "XN Technologies, Inc."),
	__AQ_PNP_PROP("XOC", "Invalid Vendor Codename - XOC"),
	__AQ_PNP_PROP("XQU", "SHANGHAI SVA-DAV ELECTRONICS CO., LTD"),
	__AQ_PNP_PROP("XRC", "Xircom Inc"),
	__AQ_PNP_PROP("XRO", "XORO ELECTRONICS (CHENGDU) LIMITED"),
	__AQ_PNP_PROP("XSN", "Xscreen AS"),
	__AQ_PNP_PROP("XST", "XS Technologies Inc"),
	__AQ_PNP_PROP("XSY", "XSYS"),
	__AQ_PNP_PROP("XTD", "Icuiti Corporation"),
	__AQ_PNP_PROP("XTE", "X2E GmbH"),
	__AQ_PNP_PROP("XTL", "Crystal Computer"),
	__AQ_PNP_PROP("XTN", "X-10 (USA) Inc"),
	__AQ_PNP_PROP("XYC", "Xycotec Computer GmbH"),
	__AQ_PNP_PROP("XYE", "Shenzhen Zhuona Technology Co., Ltd."),
	__AQ_PNP_PROP("YED", "Y-E Data Inc"),
	__AQ_PNP_PROP("YHQ", "Yokogawa Electric Corporation"),
	__AQ_PNP_PROP("YHW", "Exacom SA"),
	__AQ_PNP_PROP("YMH", "Yamaha Corporation"),
	__AQ_PNP_PROP("YOW", "American Biometric Company"),
	__AQ_PNP_PROP("ZAN", "Zandar Technologies plc"),
	__AQ_PNP_PROP("ZAX", "Zefiro Acoustics"),
	__AQ_PNP_PROP("ZAZ", "ZeeVee, Inc."),
	__AQ_PNP_PROP("ZBR", "Zebra Technologies International, LLC"),
	__AQ_PNP_PROP("ZBX", "Zebax Technologies"),
	__AQ_PNP_PROP("ZCT", "ZeitControl cardsystems GmbH"),
	__AQ_PNP_PROP("ZDS", "Zenith Data Systems"),
	__AQ_PNP_PROP("ZEN", "ZENIC Inc."),
	__AQ_PNP_PROP("ZGT", "Zenith Data Systems"),
	__AQ_PNP_PROP("ZIC", "Nationz Technologies Inc."),
	__AQ_PNP_PROP("ZMC", "HangZhou ZMCHIVIN"),
	__AQ_PNP_PROP("ZMT", "Zalman Tech Co., Ltd."),
	__AQ_PNP_PROP("ZMZ", "Z Microsystems"),
	__AQ_PNP_PROP("ZNI", "Zetinet Inc"),
	__AQ_PNP_PROP("ZNX", "Znyx Adv. Systems"),
	__AQ_PNP_PROP("ZOW", "Zowie Intertainment, Inc"),
	__AQ_PNP_PROP("ZRN", "Zoran Corporation"),
	__AQ_PNP_PROP("ZSE", "Zenith Data Systems"),
	__AQ_PNP_PROP("ZTC", "ZyDAS Technology Corporation"),
	__AQ_PNP_PROP("ZTE", "ZTE Corporation"),
	__AQ_PNP_PROP("ZTI", "Zoom Telephonics Inc"),
	__AQ_PNP_PROP("ZTM", "ZT Group Int'l Inc."),
	__AQ_PNP_PROP("ZTT", "Z3 Technology"),
	__AQ_PNP_PROP("ZWE", "Shenzhen Zowee Technology Co., LTD"),
	__AQ_PNP_PROP("ZYD", "Zydacron Inc"),
	__AQ_PNP_PROP("ZYP", "Zypcom Inc"),
	__AQ_PNP_PROP("ZYT", "Zytex Computers"),
	__AQ_PNP_PROP("ZYX", "Zyxel"),
	__AQ_PNP_PROP("ZZZ", "Boca Research Inc"),

};
#undef __AQ_PNP_PROP
